@@ -12,9 +12,9 @@
 
 #include "libkita/favoritethreads.h"
 #include "libkita/kita_misc.h"
-#include "libkita/threadinfo.h"
 #include "libkita/signalcollection.h"
-#include "libkita/parsemisc.h"
+#include "libkita/datmanager.h"
+#include "libkita/boardmanager.h"
 
 #include <qmap.h>
 #include <qapplication.h>
@@ -32,8 +32,6 @@
 FavoriteListView::FavoriteListView( QWidget* parent, const char* name )
         : Kita::ThreadListView( parent, name )
 {
-    subjectList->addColumn( i18n( "Board" ) );
-
     KindLabel->hide();
 
     Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
@@ -43,13 +41,11 @@ FavoriteListView::FavoriteListView( QWidget* parent, const char* name )
              SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
     connect( ReloadButton, SIGNAL( clicked() ),
              SLOT( slotReloadButton() ) );
-    connect( this, SIGNAL( openBoardRequested( const QString&, bool ) ),
-             signalCollection, SIGNAL( openBoardRequested( const QString&, bool ) ) );
     connect( signalCollection, SIGNAL( favoritesUpdated() ),
              SLOT( update() ) );
 
     connect( signalCollection, SIGNAL( updateSubjectTab( const KURL& ) ),
-             SLOT( slotUpdateSubject( const KURL& ) ) );  
+             SLOT( slotUpdateSubject( const KURL& ) ) );
 }
 
 FavoriteListView::~FavoriteListView()
@@ -68,30 +64,28 @@ void FavoriteListView::update()
 
     subjectList->clear();
 
-    KitaThreadInfo* cache = KitaThreadInfo::getInstance();
-
     QValueList<QString>::const_iterator it;
     for ( it = threadList.begin(); it != threadList.end(); ++it ) {
-        const Kita::Thread* thread = Kita::Thread::getByURL( *it );
+        QString datURL = ( *it );
 
         QDateTime since;
-        since.setTime_t( Kita::datToSince( thread->datURL() ) );
+        since.setTime_t( Kita::datToSince( datURL ) );
 
-        int readNum = cache->readNum( thread->datURL() );
-        int resNum = KitaThreadInfo::resNum( thread->datURL() );
+        int viewPos = Kita::DatManager::getViewPos( datURL );
+        int resNum = Kita::DatManager::getResNum( datURL );
 
         KListViewItem* item = new KListViewItem( subjectList );
-        item->setText( Col_Board, thread->boardName() );
-        item->setText( Col_Subject, Kita::unescape( thread->name() ) );
-        item->setText( Col_Read, QString( "%1" ).arg( readNum, 4 ) );
+        item->setText( Col_Board, Kita::BoardManager::boardName( datURL ) );
+        item->setText( Col_Subject, Kita::DatManager::threadName( datURL ) );
+        item->setText( Col_ReadNum, QString( "%1" ).arg( viewPos, 4 ) );
         if ( resNum > 0 ) {
             item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
-            if ( resNum != readNum ) {
-                item->setText( Col_Unread, QString( "%1" ).arg( resNum - readNum, 4 ) );
+            if ( resNum != viewPos ) {
+                item->setText( Col_Unread, QString( "%1" ).arg( resNum - viewPos, 4 ) );
             }
         }
         item->setText( Col_Since, since.toString( "yy/MM/dd hh:mm" ) );
-        item->setText( Col_DatURL, thread->datURL() );
+        item->setText( Col_DatURL, datURL );
     }
     subjectList->setSorting( Col_Board );
 }
@@ -104,24 +98,23 @@ void FavoriteListView::loadThread( QListViewItem* item )
 
     QValueList<QString>::const_iterator it;
     for ( it = threadList.begin(); it != threadList.end(); ++it ) {
-        const Kita::Thread* thread = Kita::Thread::getByURL( *it );
+        QString datURL = ( *it );
 
-        if ( thread->datURL() == item->text( Col_DatURL ) ) {
-            emit showThreadRequested( thread->datURL(), false );
+        if ( datURL == item->text( Col_DatURL ) ) {
+            emit openURLRequestExt( datURL, KParts::URLArgs(), "kita_open_2chthread", 0 );
         }
     }
 }
 
 void FavoriteListView::slotUpdateSubject( const KURL& url )
 {
-    KURL datURL = Kita::ParseMisc::parseURLonly( url );
-    Kita::Thread* updated_thread = Kita::Thread::getByURLNew( datURL );
+    KURL datURL = Kita::getDatURL( url );
     for ( QListViewItem * item = subjectList->firstChild(); item; item = item->nextSibling() ) {
         if ( item->text( Col_DatURL ) == datURL.prettyURL() ) {
-            int resNum = updated_thread->resNum();
-            int readNum = KitaThreadInfo::readNum( updated_thread->datURL() );
+            int resNum = Kita::DatManager::getResNum( datURL );
+            int viewPos = Kita::DatManager::getViewPos( datURL );
             item->setText( Col_ResNum, QString( "%1" ).arg( resNum, 4 ) );
-            item->setText( Col_Read, QString( "%1" ).arg( readNum, 4 ) );
+            item->setText( Col_ReadNum, QString( "%1" ).arg( viewPos, 4 ) );
         }
     }
 }
@@ -129,32 +122,48 @@ void FavoriteListView::slotUpdateSubject( const KURL& url )
 // TODO: KitaSubjectView饹Ʊ᥽åɤȤۤȤƱ
 void FavoriteListView::slotContextMenuRequested( QListViewItem* item, const QPoint& point, int )
 {
+    enum {
+        Menu_OpenWithBrowser,
+        Menu_OpenWithNewTab,
+        Menu_CopyURL,
+        Menu_CopyTitleAndURL,
+        Menu_RemoveFromFavorites
+    };
+
     if ( item == 0 ) {
         return ;
     }
 
     KPopupMenu popup( 0 );
-    popup.insertItem( i18n( "Open with Web Browser" ), 0 );
-    popup.insertItem( i18n( "Open with new tab" ), 1 );
-    popup.insertItem( i18n( "Copy title and URL" ), 2 );
-    popup.insertItem( i18n( "Remove from Favorites" ), 3 );
+    popup.insertItem( i18n( "Open with Web Browser" ), Menu_OpenWithBrowser );
+    popup.insertItem( i18n( "Open with new tab" ), Menu_OpenWithNewTab );
+    popup.insertItem( i18n( "Copy URL" ), Menu_CopyURL );
+    popup.insertItem( i18n( "Copy title and URL" ), Menu_CopyTitleAndURL );
+    popup.insertItem( i18n( "Remove from Favorites" ), Menu_RemoveFromFavorites );
 
-    Kita::Thread* thread = Kita::Thread::getByURL( item->text( Col_DatURL ) );
+    QString datURL = item->text( Col_DatURL );
+    QString threadURL = Kita::DatManager::threadURL( datURL );
 
     QClipboard* clipboard = QApplication::clipboard();
+    QString cliptxt;
 
     switch ( popup.exec( point ) ) {
-    case 0:
-        KRun::runURL( thread->url(), "text/html" );
+    case Menu_OpenWithBrowser:
+        KRun::runURL( Kita::DatManager::threadURL( datURL ), "text/html" );
         break;
-    case 1:
-        emit showThreadRequested( thread->datURL(), true );
+    case Menu_OpenWithNewTab:
+        emit openURLRequestExt( datURL, KParts::URLArgs(), "kita_open_2chthread", 1 );
         break;
-    case 2:
-        clipboard->setText( thread->name() + "\n" + thread->url() );
+    case Menu_CopyURL:
+        clipboard->setText( threadURL );
         break;
-    case 3:
-        emit bookmarked( thread->datURL(), false );
+    case Menu_CopyTitleAndURL:
+	cliptxt = Kita::DatManager::threadName( datURL ) + "\n" + threadURL;
+	clipboard->setText( cliptxt , QClipboard::Clipboard );
+	clipboard->setText( cliptxt , QClipboard::Selection );
+        break;
+    case Menu_RemoveFromFavorites:
+        emit bookmarked( datURL, false );
         break;
     default:
         break;
@@ -164,12 +173,12 @@ void FavoriteListView::slotContextMenuRequested( QListViewItem* item, const QPoi
 void FavoriteListView::slotReloadButton()
 {
     QValueList<QString> boardList;
-    
+
     const QValueList<QString> threadList = FavoriteThreads::getInstance() -> threadList();
     QValueList<QString>::const_iterator it;
     for ( it = threadList.begin(); it != threadList.end(); ++it ) {
-        const Kita::Thread* thread = Kita::Thread::getByURL( *it );
-        QString boardURL = Kita::datToBoard( thread->datURL() );
+        QString datURL = ( *it );
+        QString boardURL = Kita::datToBoard( datURL );
         if ( boardList.contains( boardURL ) == 0 ) {
             boardList.append( boardURL );
         }
@@ -177,8 +186,11 @@ void FavoriteListView::slotReloadButton()
 
     QValueList<QString>::const_iterator it2;
     for ( it2 = boardList.begin(); it2 != boardList.end(); ++it2 ) {
-        // Ĥsubject.txt
-        Kita::Board::getThreadList( (*it2 ) );
+
+	bool online = TRUE;
+	QPtrList<Kita::Thread> threadList;
+	QPtrList<Kita::Thread> tmpList;
+	Kita::BoardManager::getThreadList( ( *it2 ), FALSE, online, threadList, tmpList );
     }
 }
 
