@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto                                  *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -20,14 +20,16 @@
 #include "kitasubjecttabwidget.h"
 #include "kitaimgtabwidget.h"
 #include "kitawritetabwidget.h"
+#include "favoriteswindow.h"
 
 #include "libkita/favoritethreads.h"
 #include "libkita/kita_misc.h"
 #include "libkita/kitaconfig.h"
 #include "libkita/signalcollection.h"
-#include "libkita/parsemisc.h"
 #include "libkita/account.h"
 #include "libkita/imgmanager.h"
+#include "libkita/datmanager.h"
+#include "libkita/boardmanager.h"
 
 #include <qdragobject.h>
 #include <qtextcodec.h>
@@ -60,11 +62,15 @@
 #include <kaboutdata.h>
 #include <kparts/partmanager.h>
 #include <kdeversion.h>
+#include <kglobal.h>
 
 KitaMainWindow::KitaMainWindow()
         : KParts::DockMainWindow( 0, "Kita" ),
         m_printer( 0 )
 {
+    // FIXME: merge *.po
+    KGlobal::locale()->insertCatalogue( "kitapart" );
+
     // accept dnd
     setAcceptDrops( true );
 
@@ -80,12 +86,6 @@ KitaMainWindow::KitaMainWindow()
     // load cache
     loadCache();
 
-    // load favorites
-    loadFavorites();
-
-    // load favorite boards;
-    loadFavoriteBoards();
-
     // load completion
     loadCompletion();
 
@@ -174,15 +174,28 @@ KitaMainWindow::KitaMainWindow()
     connect( m_urlLine, SIGNAL( returnPressed() ),
              SLOT( slotURLLine() ) );
 
-    connect( m_subjectTab, SIGNAL( showThreadRequested( const QString&, bool ) ),
-             m_threadDock, SLOT( slotShowThread( const QString&, bool ) ) );
-
     QPopupMenu* settingsPopup = static_cast<QPopupMenu *>( factory() ->container( "settings", this ) );
     connect( settingsPopup, SIGNAL( aboutToShow() ),
              SLOT( settingsMenuAboutToShow() ) );
 
-    // load boad list & show board dock
-    m_boardTab->loadBoardList();
+    // load favorite boards;
+    loadFavoriteBoards();
+
+    // load boad list
+    {
+        QString configPath = locateLocal( "appdata", "board_list" );
+        if ( QFile::exists( configPath ) ) {
+            m_boardTab->showBoardList();
+            m_boardTab->loadOpened();
+        } else {
+            m_boardTab->updateBoardList();
+        }
+    }
+
+    // load favorites
+    loadFavorites();
+
+    // show board dock
     m_boardDock->slotShowDock();
 
     // update favorite list
@@ -216,7 +229,7 @@ KitaMainWindow::~KitaMainWindow()
     saveFavoriteBoards();
 
     saveFavorites();
-
+    
     saveCache();
 
     saveMainWindowSettings( KGlobal::config(), "MainWindow" );
@@ -232,6 +245,8 @@ KitaMainWindow::~KitaMainWindow()
     delete m_naviDock;
     delete m_imgDock;
     delete m_writeDock;
+
+    Kita::DatManager::deleteAllDatInfo();
 }
 
 void KitaMainWindow::load( const KURL& url )
@@ -320,10 +335,17 @@ void KitaMainWindow::setupActions()
     KStdAction::configureToolbars( this, SLOT( optionsConfigureToolbars() ), actionCollection() );
     KStdAction::preferences( this, SLOT( optionsPreferences() ), actionCollection() );
 
-    new KAction( i18n( "Load BoardList" ),
+/*    new KAction( i18n( "Edit Favorites" ),
+                 0,
+                 this,
+                 SLOT( favoritesEdit() ),
+                 actionCollection(),
+                 "favorites_edit" );*/
+
+    new KAction( i18n( "Load board list" ),
                  0,
                  m_boardTab,
-                 SLOT( loadBoardList() ),
+                 SLOT( updateBoardList() ),
                  actionCollection(),
                  "load_board_list" );
 
@@ -383,8 +405,8 @@ void KitaMainWindow::setupActions()
 void KitaMainWindow::slotURLLine()
 {
     KURL url = m_urlLine->text();
-    KURL datURL = Kita::ParseMisc::parseURLonly( url );
-    m_threadDock->slotShowThread( datURL.prettyURL(), KitaConfig::alwaysUseTab() );
+    KURL datURL = Kita::getDatURL( url );
+    m_threadDock->slotShowThread( datURL, KitaConfig::alwaysUseTab() );
 }
 
 void KitaMainWindow::saveProperties( KConfig* )
@@ -742,6 +764,7 @@ void KitaMainWindow::slotCheckWriteToggleAction( bool check )
 }
 
 
+/* open url */ /* public slot */ /* obsolete */
 void KitaMainWindow::slotOpenURLRequest( const KURL& url, const KParts::URLArgs& args )
 {
     slotOpenURLRequestExt( url, args );
@@ -750,6 +773,8 @@ void KitaMainWindow::slotOpenURLRequest( const KURL& url, const KParts::URLArgs&
 
 /* open url */
 /*
+  If mimetype == "kita_open_2chboard", open the board.
+  If mimetype == "kita_open_2chthread",  open the thread.
   If mimetype == "text/html", open url with web browser.
   if mimetype == QString::null, use KIO::NetAccess::mimetype to decide mime type of url.
  
@@ -767,16 +792,34 @@ void KitaMainWindow::slotOpenURLRequestExt(
     kdDebug() << QString( "NewTab: %1, reload: %2" )
     .arg( args.newTab() ? "yes" : "no" )
     .arg( args.reload ? "yes" : "no" ) << endl;
-    KURL datURL = Kita::ParseMisc::parseURLonly( url ); /* convert "thread URL" into "dat URL" */
 
-    /*  open url with web browser, and return. */
-    if ( mimetype == "text/html" ) {
+    /* open 2ch board */
+    /* if usr1 == 1, open the board with new tab. */
+    if ( mimetype == "kita_open_2chboard" ) {
+        bool withNewTab = ( usr1 == 1 );
+        m_subjectDock->slotLoadBoard( url, withNewTab );
+        return ;
+    }
+
+    /* open 2ch thread */
+    /* if usr1 == 1, open the thread with new tab. */
+    if ( mimetype == "kita_open_2chthread" ) {
+        bool withNewTab = ( usr1 == 1 );
+        m_threadDock->slotShowThread( url, withNewTab );
+        return ;
+    }
+
+    /*  open url with web browser, etc. */
+    if ( mimetype != QString::null ) {
         KRun::runURL( url, mimetype );
         return ;
     }
 
-    QRegExp regexp( "http://([^/]*)/([^/]*)/dat/(.*)\\.dat$" );
-    if ( regexp.search( datURL.url() ) == -1 ) { /* Is this URL 2ch? */
+    /* open thread with new thread tab */
+    if ( Kita::DatManager::isThreadEnrolled( url ) ){
+	m_threadDock->slotShowThread( url, true );
+	return;
+    }
 
         /* bmp file */
         if ( Kita::ImgManager::isBMP( url ) ) {
@@ -824,12 +867,9 @@ void KitaMainWindow::slotOpenURLRequestExt(
         }
 
         KRun::runURL( url, mimetype );
-
-    } else {
-        m_threadDock->slotShowThread( url.prettyURL(), true );
-    }
 }
 
+
 void KitaMainWindow::loadCache()
 {
     KitaThreadInfo * cache = KitaThreadInfo::getInstance();
@@ -852,6 +892,7 @@ void KitaMainWindow::saveCache()
     }
 }
 
+
 /*!
     \fn KitaMainWindow::setFont(QFont& font)
  */
@@ -1145,4 +1186,10 @@ void KitaMainWindow::login()
     }
 }
 
+void KitaMainWindow::favoritesEdit()
+{
+    FavoritesWindow* window = new FavoritesWindow( this );
+    window->show();
+}
+
 #include "kita.moc"
