@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2004 by Hideki Ikemoto , (c) 2004 by 421                *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,8 @@
 #include "libkita/imgmanager.h"
 #include "libkita/signalcollection.h"
 #include "libkita/datmanager.h"
-#include "libkita/parsemisc.h"
+#include "libkita/boardmanager.h"
+#include "libkita/kita_misc.h"
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -131,12 +132,12 @@ void KitaImgTabWidget::slotUpdateView( const KURL& url )
             KURL datURL = view->datURL();
             if ( !datURL.isEmpty() ) {
                 QString ref;
-                Kita::ParseMisc::parseURL( datURL, ref );
-                QString boardName = Kita::DatManager::boardName( datURL );
+                Kita::getDatURL( datURL, ref );
+                QString boardName = Kita::BoardManager::boardName( datURL );
                 if ( boardName != QString::null ) str = "[" + boardName + "] ";
                 str += Kita::DatManager::threadName( datURL );
                 if ( str != QString::null ) str += "\n";
-                str += Kita::DatManager::threadURL( datURL ) + ref;
+                str += Kita::getThreadURL( datURL ) + ref;
             }
             if ( str != QString::null ) str += "\n";
             str += url.prettyURL();
@@ -332,6 +333,18 @@ void KitaImgTabWidget::setupActions()
                  SLOT( slotOpenThread() ),
                  actionCollection(),
                  "imgviewer_openthread" );
+
+    m_sizeaction = new KSelectAction( i18n( "Size" ),
+                                      0,
+                                      this,
+                                      SLOT( slotSelectSize() ),
+                                      actionCollection(),
+                                      "imgviewer_selectsize" );
+
+    QStringList selectlist;
+    selectlist << "20%" << "25%" << "50%" << "75%" << "100%" << "125%"
+               << "150%" << "175%" << "200%" << "300%" << "400%" << "500%" ;
+    m_sizeaction->setItems( selectlist );
 }
 
 
@@ -552,6 +565,16 @@ void KitaImgTabWidget::slotOpenThread( int idx )
 }
 
 
+/* public slot */
+void KitaImgTabWidget::slotSelectSize()
+{
+    int size = m_sizeaction->currentText().remove( "%" ).toInt();
+
+    QWidget * w = currentPage();
+    KitaImgView* view = isImgView( w );
+    if ( view ) view->slotSetSize( size );
+}
+
 
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
