@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto                                  *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -9,6 +9,8 @@
 ***************************************************************************/
 
 #include "kitasubjecttabwidget.h"
+#include "libkita/boardmanager.h"
+#include "libkita/signalcollection.h"
 
 #include <kpopupmenu.h>
 #include <kdebug.h>
@@ -20,7 +22,6 @@
 #include <qapplication.h>
 #include <qclipboard.h>
 
-#include "libkita/signalcollection.h"
 
 KitaSubjectTabWidget::KitaSubjectTabWidget( QWidget* parent, const char* name, WFlags f )
         : KitaTabWidgetBase( parent, name, f )
@@ -28,85 +29,78 @@ KitaSubjectTabWidget::KitaSubjectTabWidget( QWidget* parent, const char* name, W
     setXMLFile( "kitasubjecttabwidgetui.rc" );
 
     setTabBar( new SubjectTabBar( this ) );
-    KitaSubjectView * view = new KitaSubjectView( this );
-    addTab( view, "        " );
-    m_latestView = view;
-    m_viewList.append( view );
 
-    m_favoriteList = new FavoriteListView( this, "favoriteTab" );
-    addTab( m_favoriteList, i18n( "Favorite" ) );
+    FavoriteListView* favoriteList = new FavoriteListView( this, "favoriteTab" );
+    addTab( favoriteList, i18n( "Favorite" ) );
 
     setupActions();
-    connectSignals( m_favoriteList );
-    connectSignals( view );
 }
 
 KitaSubjectTabWidget::~KitaSubjectTabWidget()
 {}
 
-void KitaSubjectTabWidget::loadBoard( const QString& boardURL, bool withNewTab )
+/* public slots */
+void KitaSubjectTabWidget::loadBoard( const KURL& boardURL, bool withNewTab )
 {
     KitaSubjectView * view = findView( boardURL );
-    QString boardName = Kita::Board::getName( boardURL );
+    QString boardName = Kita::BoardManager::boardName( boardURL );
+    if ( !view ) {
+
+        if ( count() == 1 || withNewTab ) view = createView( boardName );
+        else {
+
+            QWidget* w = currentPage();
+            /* currentPage is FavoriteListView. */
+            if ( !isSubjectView( w ) ) w = page( count() - 2 );
+
+            view = static_cast< KitaSubjectView *>( w );
+            view->init();	    
+            setTabLabel( view, boardName );
+        }
+    }
+
     if ( view ) {
-        m_latestView = view;
-        setTabLabel( m_latestView, boardName );
-    } else if ( withNewTab ) {
-        KitaSubjectView * newView = new KitaSubjectView( this );
-        connectSignals( newView );
-        insertTab( newView, boardName, count() - 1 );
-        m_latestView = newView;
-        m_viewList.append( newView );
-    } else {
-        setTabLabel( m_latestView, boardName );
+        showPage( view );
+        view->loadBoard( boardURL );
+    }
+}
+
+/* create KitaSubjectView */ /* private */
+KitaSubjectView* KitaSubjectTabWidget::createView( QString label )
+{
+    KitaSubjectView * view = new KitaSubjectView( this );
+    if ( view ) {
+        insertTab( view, label, count() - 1 );
+        connect( view, SIGNAL( closeCurrentTab() ), SLOT( slotCloseCurrentTab() ) );
     }
 
-    m_latestView->loadBoard( boardURL );
-    setTabToolTip( m_latestView, boardName );
-
-    showPage( m_latestView );
+    return view;
 }
 
-void KitaSubjectTabWidget::connectSignals( Kita::ThreadListView* view )
+/* private */
+KitaSubjectView* KitaSubjectTabWidget::findView( const KURL& boardURL )
 {
-    connect( view, SIGNAL( showThreadRequested( const QString&, bool ) ),
-             this, SIGNAL( showThreadRequested( const QString&, bool ) ) );
-}
+    int max = count() - 1;
+    if ( max <= 0 ) return NULL;
+    int i = 0;
 
-KitaSubjectView* KitaSubjectTabWidget::findView( const QString& boardURL )
-{
-    KitaSubjectView * view;
-    for ( view = m_viewList.first(); view; view = m_viewList.next() ) {
-        if ( view->boardURL() == boardURL ) {
-            return view;
-        }
-        if ( view->boardURL().isEmpty() ) {
-            return view;  // default view
-        }
+    while ( i < max ) {
+        KitaSubjectView * view = isSubjectView( page ( i ) );
+        if ( view && view->boardURL() == boardURL ) return view;
+        i++;
     }
-    return 0;
+
+    return NULL;
 }
 
-void KitaSubjectTabWidget::slotCurrentChanged( QWidget* widget )
-{
-    KitaTabWidgetBase::slotCurrentChanged( widget );
-}
 
 /* protected */ /* virtual */
 void KitaSubjectTabWidget::deleteWidget( QWidget* w )
 {
-    KitaSubjectView * view = static_cast<KitaSubjectView *>( w );
-    if ( count() <= 2 ) {
-        return ;
-        // favoriteȤΤȤϲ⤷ʤ
-    }
-    m_viewList.remove( view );
+    KitaSubjectView * view = isSubjectView( w );
+    if ( !view ) return ;
     removePage( view );
     delete view;
-
-    // FIXME: favoriteϰֺˤʤȤ
-    setCurrentPage( 0 );
-    m_latestView = static_cast<KitaSubjectView *>( currentPage() );
 }
 
 
@@ -133,7 +127,7 @@ void KitaSubjectTabWidget::setupActions()
                  this,
                  SLOT( slotFocusSearchCombo() ),
                  actionCollection(),
-                 "threadview_find" );
+                 "subjectview_find" );
 
     new KAction( i18n( "Reload" ),
                  "reload",
@@ -142,6 +136,27 @@ void KitaSubjectTabWidget::setupActions()
                  SLOT( slotReloadButton() ),
                  actionCollection(),
                  "subjectview_reload" );
+
+    new KAction( i18n( "New Thread" ),
+                 0,
+                 this,
+                 SLOT( slotNewThread() ),
+                 actionCollection(),
+                 "subjectview_newthread" );
+
+    new KAction( i18n( "Show Old Logs" ),
+                 0,
+                 this,
+                 SLOT( slotShowOldLogs() ),
+                 actionCollection(),
+                 "subjectview_showoldlogs" );
+    
+    new KAction( i18n( "Show Title Image" ),
+                 0,
+                 this,
+                 SLOT( slotShowTitleImg() ),
+                 actionCollection(),
+                 "subjectview_showtitleimg" );
 }
 
 /* public slot */
@@ -158,8 +173,36 @@ void KitaSubjectTabWidget::slotFocusSearchCombo()
     if ( view ) view->slotFocusSearchCombo();
 }
 
+/* public slot */
+void KitaSubjectTabWidget::slotNewThread()
+{
+    KitaSubjectView * view = isSubjectView( currentPage() );
+    if ( view ) view->slotCreateNewThread();
+}
 
 
+/* public slot */
+void KitaSubjectTabWidget::slotShowOldLogs( int idx )
+{
+    KitaSubjectView * view;
+    if( idx == -1 ) view = isSubjectView( currentPage() );
+    else  view = isSubjectView( page( idx ) );
+    if ( view ) view->toggleShowOldLogs();
+}
+
+/* public slot */
+void KitaSubjectTabWidget::slotShowTitleImg( int idx )
+{
+    KitaSubjectView * view;
+    if( idx == -1 ) view = isSubjectView( currentPage() );
+    else  view = isSubjectView( page( idx ) );
+    if ( view ){
+        KURL imgURL = Kita::BoardManager::titleImgURL( view->boardURL() );
+       if( !imgURL.isEmpty() ) {
+           emit openURLRequestExt( imgURL, KParts::URLArgs(), QString::null, 1, 0, view->boardURL() );
+       }
+    }
+}
 
 
 /*---------------------------------------------------------------------*/
@@ -185,7 +228,9 @@ void SubjectTabBar::showPopupMenu( int idx, QPoint global )
         MENU_CLOSELEFT,
         MENU_CLOSERIGHT,
         MENU_OPENBROWSER,
-        MENU_COPYTITLE
+        MENU_COPYTITLE,
+        MENU_SHOWTITLEIMG,
+        MENU_SHOWOLDLOGS
     };
 
     KitaSubjectTabWidget* tabwidget = static_cast<KitaSubjectTabWidget*>( parentWidget() );
@@ -207,9 +252,11 @@ void SubjectTabBar::showPopupMenu( int idx, QPoint global )
     collection->action( "tab_closealltab" ) ->plug( popup );
 
     popup->insertSeparator();
+    popup->insertItem( i18n( "Show Old Logs" ) , MENU_SHOWOLDLOGS );
     popup->insertItem( i18n( "Open with Web Browser" ), MENU_OPENBROWSER );
     popup->insertItem( i18n( "Copy title and URL" ), MENU_COPYTITLE );
-
+    popup->insertItem( i18n( "Show Title Image" ) , MENU_SHOWTITLEIMG );
+    
     popup->insertSeparator();
     collection->action( "tab_configkeys" ) ->plug( popup );
 
@@ -224,11 +271,13 @@ void SubjectTabBar::showPopupMenu( int idx, QPoint global )
     case MENU_CLOSEOTHER: tabwidget->slotCloseOtherTab( idx ); break;
     case MENU_CLOSERIGHT: tabwidget->slotCloseRightTab( idx ); break;
     case MENU_CLOSELEFT: tabwidget->slotCloseLeftTab( idx ); break;
+    case MENU_SHOWOLDLOGS: tabwidget->slotShowOldLogs( idx ); break;		
+    case MENU_SHOWTITLEIMG: tabwidget->slotShowTitleImg( idx ); break;
     case MENU_OPENBROWSER:
         KRun::runURL( subjectView->boardURL(), "text/html" );
         break;
     case MENU_COPYTITLE:
-        QString cliptxt = subjectView->boardName() + "\n" + subjectView->boardURL();
+        QString cliptxt = Kita::BoardManager::boardName( subjectView->boardURL() ) + "\n" + subjectView->boardURL().prettyURL();
         clipboard->setText( cliptxt , QClipboard::Clipboard );
         clipboard->setText( cliptxt , QClipboard::Selection );
         break;
@@ -268,14 +317,12 @@ KitaSubjectTabWidget* KitaSubjectDock::setup()
     Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
     connect( signalCollection, SIGNAL( switchToSubject() ),
              SLOT( slotShowDock() ) );
-    connect( signalCollection, SIGNAL( openBoardRequested( const QString&, bool ) ),
-             SLOT( slotLoadBoard( const QString&, bool ) ) );
 
     return m_subjectTab;
 }
 
 /* public slot */
-void KitaSubjectDock::slotLoadBoard( const QString& boardURL, bool withNewTab )
+void KitaSubjectDock::slotLoadBoard( const KURL& boardURL, bool withNewTab )
 {
     slotShowDock();
 
