@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto                                  *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -28,28 +28,28 @@ public:
     ~KitaSubjectTabWidget();
 
 public slots:
-    void loadBoard( const QString&, bool withNewTab = false );
+    void loadBoard( const KURL&, bool withNewTab = false );
 
 private:
-    FavoriteListView* m_favoriteList;
-    KitaSubjectView* m_latestView;
-    QPtrList<KitaSubjectView> m_viewList;
-    void connectSignals( Kita::ThreadListView* );
-    KitaSubjectView* findView( const QString& boardURL );
+    KitaSubjectView* createView( QString label );
+    KitaSubjectView* findView( const KURL& boardURL );
     KitaSubjectView* isSubjectView( QWidget* w );
-    void setupActions();
-
-private slots:
-    void slotCurrentChanged( QWidget* widget );
-    void slotReloadButton();
-    void slotFocusSearchCombo();
-
 
 protected:
     virtual void deleteWidget( QWidget* w );
 
-signals:
-    void showThreadRequested( const QString&, bool withNewTab );
+    
+    /* tab actions */
+
+private:
+    void setupActions();
+
+public slots:
+    void slotReloadButton();
+    void slotFocusSearchCombo();
+    void slotNewThread();
+    void slotShowOldLogs( int idx = -1 );
+    void slotShowTitleImg( int idx  = -1 );
 };
 
 /*--------------------------------------------------*/
@@ -89,7 +89,7 @@ public:
     KitaSubjectTabWidget* setup();
 
 public slots:
-    void slotLoadBoard( const QString& boardURL, bool withNewTab );
+    void slotLoadBoard( const KURL& boardURL, bool withNewTab );
 };
 
 
