@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto                                  *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -11,12 +11,10 @@
 #ifndef _KITASUBJECTVIEW_H_
 #define _KITASUBJECTVIEW_H_
 
-#include <qwidget.h>
 #include <kurl.h>
 #include "threadlistview.h"
-#include "part/kita2ch.h"
-#include "libkita/board.h"
 
+class QWidget;
 class KListViewItem;
 
 /**
@@ -30,30 +28,42 @@ class KitaSubjectView : public Kita::ThreadListView
 public:
     KitaSubjectView( QWidget* parent, const char* name = 0 );
     ~KitaSubjectView();
-    const QString boardURL();
-    const QString boardName();
+    void init();
+    const KURL boardURL();
+    void toggleShowOldLogs();
 
 public slots:
     virtual void setFocus();
     void slotFocusSearchCombo(); 
     void reloadSubject();
-    void loadBoard( const QString& boardURL );
+    void slotCreateNewThread();
+    void loadBoard( const KURL& url, bool online = TRUE );
     void setFont( const QFont& font );
     void slotUpdateSubject( const KURL& url );
 
 private:
-    QString m_boardURL;
+    KURL m_boardURL;
     int m_unreadNum, m_readNum, m_newNum;
+    bool m_showOldLogs;
     void UpdateKindLabel();
     void deleteLog( const KURL& url );
+    void loadLayout();
+    void updateListViewItem( QListViewItem* item, Kita::Thread* thread, const QDateTime& current, int id, int order);
+    bool eventFilter( QObject* watched, QEvent* e );
+    void saveHeaderOnOff();
+    void loadHeaderOnOff();
 
 private slots:
     void loadThread( QListViewItem* item );
     void slotContextMenuRequested( QListViewItem*, const QPoint&, int );
+    void slotCloseButton();
+    void slotSizeChange( int section, int oldSize, int newSize );
 
 signals:
     void loadBoardCompleted( const KURL& );
     void closeThreadTab( const KURL& );
+    void createNewThread( const KURL& , const QString&, const QString& );    
+    void closeCurrentTab();
 };
 
 #endif
