@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2004 by Hideki Ikemoto , (c) 2004 by 421                *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -10,12 +10,12 @@
 
 #include "kitathreadtabwidget.h"
 #include "kitathreadview.h"
-#include "kitathreadpart.h"
 
 #include "libkita/kita_misc.h"
 #include "libkita/parsemisc.h"
 #include "libkita/signalcollection.h"
 #include "libkita/datmanager.h"
+#include "libkita/boardmanager.h"
 #include "libkita/kita-utf8.h"
 
 #include <kdebug.h>
@@ -159,14 +159,14 @@ void KitaThreadTabWidget::slotShowKitaNavi(int mode,
     if( view == NULL) return;
 
     QString toolstr = tabstr + " : "+QString( "[%1] %2" )
-	.arg( Kita::DatManager::thread_boardName( datURL ) )
-	.arg( Kita::DatManager::thread_name( datURL ) ); 
+	.arg( Kita::BoardManager::boardName( datURL ) )
+	.arg( Kita::DatManager::threadName( datURL ) ); 
     
     view->setup( datURL, VIEWMODE_KITANAVI );
     setTabToolTip( view , toolstr );
     totalNum = Kita::DatManager::getResNum( datURL );
 
-    labelstr = Kita::DatManager::thread_name( datURL ) + " : " + tabstr;
+    labelstr = Kita::DatManager::threadName( datURL ) + " : " + tabstr;
     
     /*---------------------------------------------*/    
     /* copy data from DatManager to KitaThreadView */
@@ -258,10 +258,10 @@ void KitaThreadTabWidget::slotShowKitaNavi(int mode,
     case KITANAVI_SHOWREVRESTREE:	
 
 	str = QString("[%1] %2 : No.%3 [%4]<br>")
-	    .arg( Kita::DatManager::thread_boardName( datURL ) )
-	    .arg( Kita::DatManager::thread_name( datURL ) )
+	    .arg( Kita::BoardManager::boardName( datURL ) )
+	    .arg( Kita::DatManager::threadName( datURL ) )
 	    .arg(startnum ).arg( endnum );
-	urlstr = Kita::DatManager::thread_url( datURL ) + QString().setNum( startnum );
+	urlstr = Kita::DatManager::threadURL( datURL ) + QString().setNum( startnum );
 	str += "<a href=\""+urlstr+"\">"+urlstr+"</a><br>";
 	str += Kita::DatManager::getHtml( datURL, startnum, startnum );
 	if( endnum ){
@@ -307,29 +307,7 @@ void KitaThreadTabWidget::slotCloseThreadTab( const KURL& url )
 /* create KitaThreadView */   /* private */
 KitaThreadView* KitaThreadTabWidget::createView( QString label )
 {
-    if( m_manager == NULL ) return NULL;
-
-    /* setup lib factory */
-    KLibFactory* factory = KLibLoader::self()->factory( "libkitapart" );
-    if ( ! factory ){
-        QMessageBox::critical( parentWidget(),
-                               i18n( "Load Error" ),
-                               i18n( "can't load libkitapart." ) );
-	return NULL;
-    }
-    
-    KitaThreadPart* part
-	= static_cast<KitaThreadPart *>( factory->create( this, "thread", "KitaThreadPart" ) );
-
-    if( !part ){
-       QMessageBox::critical( parentWidget(),
-                               i18n( "Load Error" ),
-                               i18n( "can't create KitaThreadPart." ) );
-	return NULL;
-    }
-
-    m_manager->addPart( part );
-    KitaThreadView* view = static_cast<KitaThreadView *>( part->widget() );
+    KitaThreadView* view = new KitaThreadView( this );
     if( view ){
 	addTab( view, label );
 	connect( view, SIGNAL( closeCurrentTab() ), SLOT( slotCloseCurrentTab() ) );
@@ -441,6 +419,8 @@ void KitaThreadTabWidget::deleteWidget( QWidget* w )
 /* private */
 void KitaThreadTabWidget::setupActions()
 {
+    KStdAction::copy( this, SLOT( slotCopyText() ), actionCollection() );
+    
     new KAction( i18n( "Open with Web Browser" ),
                  0,
                  this,
@@ -533,6 +513,18 @@ void KitaThreadTabWidget::setupActions()
 
 /* KitaThreadView actions */
 
+/* copy selected text (Ctrl+C) */ /* public slot */
+void KitaThreadTabWidget::slotCopyText()
+{
+    QWidget* w = currentPage();
+    KitaThreadView * view = isThreadView( w );
+    if( view ){
+	QClipboard * clipboard = QApplication::clipboard();
+	QString text = view->selectedText();
+	clipboard->setText( text, QClipboard::Clipboard );
+    }
+}
+
 /* public slot */
 void KitaThreadTabWidget::slotOpenBrowser( int idx )
 {
@@ -766,13 +758,13 @@ KitaThreadTabWidget* KitaThreadDock::setupAsMainView()
 
     Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
     connect( signalCollection, SIGNAL( switchToThread() ),
-	     SLOT( slotShowDock() ) );
+	     SLOT( slotShowThreadDock() ) );
     
     return m_threadTab;
 }
 
 /* public slot */
-void KitaThreadDock::slotShowThread( const QString& url, bool withNewTab )
+void KitaThreadDock::slotShowThread( const KURL& url, bool withNewTab )
 {
     showDock();
 
@@ -793,7 +785,7 @@ KitaThreadTabWidget* KitaThreadDock::setupAsKitaNavi()
 
     Kita::SignalCollection* signalCollection = Kita::SignalCollection::getInstance();
     connect( signalCollection, SIGNAL( switchToKitanavi() ),
-	     SLOT( slotShowDock() ) );
+	     SLOT( slotShowThreadDock() ) );
     
     return m_threadTab;
 }
@@ -819,6 +811,17 @@ void KitaThreadDock::connectNaviSignals()
 }
 
 
+/* show Thread Dock */ /* private slot */
+void KitaThreadDock::slotShowThreadDock()
+{
+    QWidget* topWidget = topLevelWidget();
+    if ( topWidget->isMinimized() ) topWidget->showNormal();
+    topWidget->raise();
+    topWidget->setActiveWindow();
+
+    slotShowDock();
+}
+
 /* show res */  /* private slot */
 void KitaThreadDock::slotShowKitaNavi( const KURL& datURL, int startnum, int endnum )
 {
