@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003-2004 by Hideki Ikemoto                             *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -31,29 +31,32 @@ namespace Kita
         Q_OBJECT
 
     public:
-        Access( const KURL& datURL ) : m_datURL( datURL ), m_currentJob( 0 ) {};
+        Access( const KURL& datURL );
         virtual ~Access() {};
 
+	void init();
         QString get();
         void killJob();
         void stopJob();
         int serverTime();
-        QString getcache();
-        QString getupdate();
+        void getcache();
+        bool getupdate( int readNum );
         int responseCode();
-        static bool deleteLog( const Thread* thread );
 
     protected:
         void writeCacheData();
-        void make_cacheDir( const KURL& url );
+        void emitDatLineList( const QString& dataStream );	
 
         const KURL m_datURL;
         KIO::Job* m_currentJob;
         QString m_threadData;
         QString m_header;
-        QString m_orgData;
+        int m_dataSize;
         bool m_firstReceive;
         bool m_invalidDataReceived;
+        int m_bbstype;	
+        int m_readNum;
+        QString m_lastLine;
 
     private slots:
         void slotReceiveThreadData( KIO::Job* job, const QByteArray& data );
@@ -61,7 +64,7 @@ namespace Kita
 
     signals:
         void redirection( const QString& );
-        void receiveData( const QString& );
+        void receiveData( const QStringList& );
         void finishLoad();
     };
 
