@@ -8,8 +8,7 @@
 *   (at your option) any later version.                                   *
 ***************************************************************************/
 #include "cache.h"
-
-#include "kita_misc.h"
+#include "boardmanager.h"
 
 #include <kurl.h>
 #include <kglobal.h>
@@ -27,14 +26,85 @@ QString Cache::baseDir()
     return dir;
 }
 
-QString Cache::getPath( const KURL& datURL )
+
+QString Cache::serverDir( const KURL& url )
 {
-    QString path = Kita::datToCache( datURL.url() );
-    if ( path == QString::null ) return QString::null;
-    return baseDir() + path;
+    /* Is board enrolled ? */
+    BoardData* bdata = BoardManager::getBoardData( url );
+    if( bdata == NULL ) return QString::null;
+    
+    QString root = bdata->hostName() + bdata->rootPath();
+    
+    return root.remove( "http://" ).replace( "/", "_" ) + "/";
 }
 
 
+QString Cache::boardDir( const KURL& url )
+{
+    /* Is board enrolled ? */
+    BoardData* bdata = BoardManager::getBoardData( url );
+    if( bdata == NULL ) return QString::null;
+    
+    QString bbs = bdata->bbsPath();
+    
+    return bbs.mid( 1 ).replace( "/", "_" ) + "/";
+}
+
+
+QString Cache::getPath( const KURL& url )
+{
+    QString path = baseDir() + serverDir( url ) + boardDir( url );
+    if ( path == QString::null ) return QString::null;
+
+//    qDebug( "%s -> %s",url.prettyURL().ascii(),path.ascii());
+    
+    return path + url.fileName();
+}
+
+QString Cache::getIndexPath( const KURL& url )
+{
+    QString path = getPath( url );
+    if ( path == QString::null ) {
+        return QString::null;
+    } else {
+        return path + ".idx";
+    }
+}
+
+
+/*------------------------------------*/
+/* for SETTING.TXT and BBS history    */
+
+
+/* public */
+QString Cache::getSettingPath( const KURL& url )
+{
+    QString path = baseDir() + serverDir( url ) + boardDir( url );
+    if ( path == QString::null ) return QString::null;
+    
+    return path + "SETTING.TXT";
+}
+
+/* public */
+QString Cache::getBBSHistoryPath( const KURL& url )
+{
+    QString path = baseDir() + serverDir( url ) + boardDir( url );
+    if ( path == QString::null ) return QString::null;
+    
+    return path + "BBSHISTORY";
+}
+
+/* public */
+QString Cache::getSubjectPath( const KURL& url )
+{
+    QString path = baseDir() + serverDir( url ) + boardDir( url );
+    if ( path == QString::null ) return QString::null;
+    
+    return path + "subject.txt";
+}
+
+
+
 /*------------------------------------*/
 /* for Image files                    */
 
@@ -86,7 +156,7 @@ QString Cache::hashString( const KURL& url )
 /* private */
 QString Cache::getImgBaseDir()
 {
-    QString basedir = baseDir() + "image/";    
+    QString basedir = baseDir() + "image/";
     return basedir;
 }
 
@@ -98,6 +168,6 @@ QString Cache::getImgFileName( const KURL& url )
     host.replace( QChar( '.' ), QChar( '_' ) );
 
     QString filename = url.fileName().lower();
-   
-    return host +  "_" +  hashString( url ) + filename;
+
+    return host + "_" + hashString( url ) + filename;
 }
