@@ -22,16 +22,23 @@ namespace Kita
     */
     class Cache
     {
-        static QString baseDir();
-	static QString subDir( const KURL& url );
-	static QString hashString( const KURL& url );
-	static QString getImgBaseDir();
-	static QString getImgFileName( const KURL& src);
+        static QString subDir( const KURL& url );
+        static QString hashString( const KURL& url );
+        static QString getImgBaseDir();
+        static QString getImgFileName( const KURL& src );
 
     public:
+        static QString baseDir();
+        static QString serverDir( const KURL& url );
+        static QString boardDir( const KURL& url );
+	
         static QString getPath( const KURL& url );
-	static QString getImgPath( const KURL& url);
-	static QString getImgIdxPath( const KURL& url);	
+        static QString getIndexPath( const KURL& url );
+        static QString getSettingPath( const KURL& url );
+        static QString getBBSHistoryPath( const KURL& url );
+        static QString getSubjectPath( const KURL& url );		
+        static QString getImgPath( const KURL& url );
+        static QString getImgIdxPath( const KURL& url );
     };
 
 }
