@@ -1,5 +1,5 @@
-/**************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto , (c)2004 by 421                 *
+/***************************************************************************
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -18,15 +18,15 @@
 
 #include "datinfo.h"
 #include "datmanager.h"
-#include "parsemisc.h"
 #include "access.h"
 #include "thread.h"
-#include "threadinfo.h"
 #include "kitaconfig.h"
 #include "kita-utf8.h"
 #include "kita-utf16.h"
 #include "kita_misc.h"
 #include "account.h"
+#include "threadindex.h"
+#include "cache.h"
 
 
 using namespace Kita;
@@ -41,15 +41,32 @@ using namespace Kita;
 DatInfo::DatInfo( const KURL& url ) : m_access ( 0 ), m_access2( 0 )
 {
     QString refstr;
-    m_datURL = Kita::ParseMisc::parseURL( url, refstr );
-    m_thread = Kita::Thread::getByURLNew( m_datURL );
+    m_datURL = Kita::getDatURL( url, refstr );
 
+    /* get the pointer of Thread class */
+    m_thread = Kita::Thread::getByURLNew( m_datURL );
+    if( m_thread == NULL ){
+
+	/* create Thread */
+	m_thread = Kita::Thread::getByURL( m_datURL );
+	if( m_thread == NULL ) return;
+	
+	/* read idx file */
+	ThreadIndex::loadIndex( m_thread, m_datURL );
+    }
+
+    m_thread = Thread::getByURL( m_datURL );
+    
     /* japanese strings */
     m_spacestr = ". ";
-    m_framestr1 = ParseMisc::utf8ToUnicode( KITAUTF8_FRAME1 ); /* |  */
-    m_framestr2 = ParseMisc::utf8ToUnicode( KITAUTF8_FRAME2 ); /* |- */
-    m_framestr3 = ParseMisc::utf8ToUnicode( KITAUTF8_FRAME3 ); /* L  */
+    m_framestr1 = Kita::utf8ToUnicode( KITAUTF8_FRAME1 ); /* |  */
+    m_framestr2 = Kita::utf8ToUnicode( KITAUTF8_FRAME2 ); /* |- */
+    m_framestr3 = Kita::utf8ToUnicode( KITAUTF8_FRAME3 ); /* L  */
 
+    /* make directory */
+    QString cacheDir = Cache::baseDir() + Cache::serverDir( m_datURL ) + Cache::boardDir( m_datURL );
+    if( !Kita::mkdir( cacheDir ) ) return;
+    
     initPrivate();
 }
 
@@ -68,23 +85,29 @@ void DatInfo::init()
     return initPrivate();
 }
 
-/* private */
-void DatInfo::initPrivate()
+/* public */
+void DatInfo::wait()
+{
+    QMutexLocker locker( &m_mutex );
+}
+
+/* Init. If loadCache = TRUE, load data from cache. */ /* private */
+void DatInfo::initPrivate( bool loadCache )
 {
 
     /* stop & delete dat loader */
     deleteAccessJob();
 
     /* init variables */
-    m_readNum = 0;
     m_rawData = QString::null;
-    m_subject = QString::null;
     m_broken = FALSE;
     m_lock = 0;
     m_nowLoading = FALSE;
     m_lastLine = QString::null;
-    m_kokoyonNum = KitaThreadInfo::readNum( m_datURL.prettyURL() );
 
+    /* reset readNum  */
+    m_thread->setReadNum( 0 ); 
+    
     /* clear ResDatVec */
     m_resDatVec.clear();
     increaseResDatVec( RESDAT_DEFAULTSIZE );
@@ -95,13 +118,18 @@ void DatInfo::initPrivate()
     /* create dat loader */
     m_access = new Kita::Access( m_datURL );
 
-    connect( m_access, SIGNAL( receiveData( const QString& ) ),
-             SLOT( slotReceiveData( const QString& ) ) );
+    connect( m_access, SIGNAL( receiveData( const QStringList& ) ),
+             SLOT( slotReceiveData( const QStringList& ) ) );
     connect( m_access, SIGNAL( finishLoad() ), SLOT( slotFinishLoad() ) );
 
-    /* get dat from cahce & copy it to buffer */
-    copyRawDataToBuffer( m_access->getcache() );
-    copyRawDataToBuffer( QString::null ); /* copy the last line */
+    if( !loadCache ) return;
+    
+    /* get dat from cahce   */
+    /* slotReceiveData() is called from Access::getcache() */
+    m_access->getcache();
+
+    /* save thread information */
+    if( m_thread->readNum() ) ThreadIndex::saveIndex( m_thread, m_datURL );
 }
 
 
@@ -145,88 +173,8 @@ void DatInfo::deleteAccessJob()
     }
 }
 
-/* copy raw lines to buffer */
 
-/*  !! NOTICE!!
-   You need to call this function last
-   with rawData = QString::null in order
-   to copy the last line to buffer.      */ /* private */
-void DatInfo::copyRawDataToBuffer( const QString& rawData )
-{
-    QStringList linelist;
-    int basenum = m_readNum + 1;
-
-    // hack for machiBBS
-    if ( Kita::boardType( m_datURL.url() ) == Board_MachiBBS && m_lastLine == QString::null && m_access->responseCode() == 200 ) {
-        basenum = 1;
-        m_readNum = 0;
-    }
-
-    bool endIsLF = FALSE;
-    if ( rawData != QString::null ) {
-
-        if ( rawData.at( rawData.length() - 1 ) == '\n' ) endIsLF = TRUE;
-
-        /* split the raw data */
-        m_lastLine += rawData;
-        linelist = QStringList::split( "\n", m_lastLine );
-
-        /* backup the last line */
-        QStringList::iterator lastit = linelist.end();
-        lastit--;
-        if ( lastit != linelist.end() ) {
-            m_lastLine = ( *lastit );
-            linelist.remove( lastit );
-
-            /* If the last char of rawData is LF, then
-               add LF to m_lastLine, because LF was
-               removed by above QStringList::split().  */
-            if ( endIsLF ) m_lastLine += '\n';
-        } else m_lastLine = QString::null;
-
-    } else { /* If rawData == null, then copy the last line */
-
-        if ( m_lastLine != QString::null
-                && m_lastLine.contains( "<>" ) == 4
-                && m_lastLine.at( m_lastLine.length() - 1 ) == '\n' ) {
-
-            m_lastLine.truncate( m_lastLine.length() - 1 ); /* remove LF */
-            linelist += m_lastLine;
-            m_lastLine = QString::null;
-        }
-    }
-
-    /* copy lines to buffer */
-    for ( QStringList::iterator it = linelist.begin();
-            it != linelist.end(); ++it, ++basenum ) {
-        if ( ( *it ) != QString::null ) {
-            QString line = ParseMisc::qcpToUnicode( ( *it ) );
-            copyOneLineToResDat( line, basenum );
-        }
-    }
-
-    updateThreadInfo();
-}
-
-void DatInfo::updateThreadInfo()
-{
-    /* update thread info */
-    if ( !m_thread && m_readNum ) {
-        m_thread = Kita::Thread::getByURL( m_datURL.prettyURL() );
-    }
-    if ( m_thread ) {
-        if ( m_thread->resNum() < m_readNum ) {
-            KitaThreadInfo::setResNum( m_datURL.prettyURL(), m_readNum );
-        }
-        KitaThreadInfo::setReadNum( m_datURL.prettyURL(), m_readNum );
-    }
-}
-
-
-
-/* copy one line to resdat.            */
-/* This private function is called in
-   copyRawDataToBuffer.                */ /* private */
+/* copy one line to resdat.            */ /* private */
 bool DatInfo::copyOneLineToResDat( const QString& line, int num )
 {
 
@@ -242,7 +190,8 @@ bool DatInfo::copyOneLineToResDat( const QString& line, int num )
 
     resdat.set = TRUE;
     resdat.linestr = line;
-    if ( m_readNum < num ) m_readNum = num;
+    if ( m_thread->readNum() < num ) m_thread->setReadNum( num );
+	
     m_rawData += line + '\n';
 
     if ( num == 1 ) parseDat ( num ); /* to get subject */
@@ -257,7 +206,6 @@ bool DatInfo::copyOneLineToResDat( const QString& line, int num )
 }
 
 
-
 /* public */
 const KURL& DatInfo::url()
 {
@@ -293,8 +241,8 @@ bool DatInfo::updateCache( const QObject* parent )
 
     connect( this, SIGNAL( finishLoad() ),
              parent, SLOT( slotFinishLoad() ) );
-
-    m_access->getupdate();
+    
+    m_access->getupdate( m_thread->readNum() );
 
     return TRUE;
 }
@@ -302,7 +250,7 @@ bool DatInfo::updateCache( const QObject* parent )
 
 /* slot called when Kita::Access
    received new data              */      /* private  slot */
-void DatInfo::slotReceiveData( const QString& newLine )
+void DatInfo::slotReceiveData( const QStringList& lineList )
 {
     int rescode = m_access->responseCode();
     if ( m_access2 ) {
@@ -311,7 +259,9 @@ void DatInfo::slotReceiveData( const QString& newLine )
 
     if ( rescode != 200 && rescode != 206 ) return ;
 
-    copyRawDataToBuffer( newLine );
+    /* copy lines to buffer */
+    int count = lineList.count();
+    for ( int i = 0; i < count ; ++i ) copyOneLineToResDat( lineList[ i ], m_thread->readNum() +1 );
 
     emit receiveData();
 }
@@ -321,11 +271,10 @@ void DatInfo::slotReceiveData( const QString& newLine )
    finished loading new dat */      /* private  slot */
 void DatInfo::slotFinishLoad()
 {
-
-    /* copy the last line */
-    copyRawDataToBuffer( QString::null );
-
-    if ( m_readNum == 0 && m_access2 == NULL && Kita::is2ch( m_datURL ) ) {
+    /* save thread information */
+    ThreadIndex::saveIndex( m_thread, m_datURL );
+    
+    if ( m_thread->readNum() == 0 && m_access2 == NULL && BoardManager::type( m_datURL ) == Board_2ch ) {
         if ( Account::isLogged() ) {
             initPrivate();
             m_access2 = new OfflawAccess( m_datURL );
@@ -372,15 +321,11 @@ int DatInfo::getServerTime()
 bool DatInfo::deleteCache()
 {
     QMutexLocker locker( &m_mutex );
-    if ( m_access == NULL ) return FALSE;
     if ( m_nowLoading ) return FALSE;
 
-    bool ret = FALSE;
-    if ( m_thread ) ret = Kita::Access::deleteLog( m_thread );
-    KitaThreadInfo::removeThreadInfo( m_datURL.prettyURL() );
-    if ( ret ) initPrivate();
+    initPrivate( FALSE );
 
-    return ret;
+    return TRUE;
 }
 
 
@@ -401,8 +346,8 @@ void DatInfo::stopLoading()
 
     /* Don't lock the mutex here !!!
        It will cause deadlock , because
-       Kita::Access::stopJob() calls KitaThreadView::slotFinishLoad() back,
-       then slotFinishLoad calls another functions in DatInfo. */
+       Kita::Access::stopJob() calls KitaHTMLPart::slotFinishLoad() back,
+       then KitaHTMLPart::slotFinishLoad() calls another functions in DatInfo. */
     if ( m_access == NULL ) return ;
     if ( ! m_nowLoading ) return ;
 
@@ -447,13 +392,6 @@ int DatInfo::isLocked()
 
 /* They are public */
 
-const QString& DatInfo::getSubject()
-{
-    QMutexLocker locker( &m_mutex );
-
-    return m_subject;
-}
-
 const QString& DatInfo::getRawDat()
 {
     QMutexLocker locker( &m_mutex );
@@ -514,7 +452,7 @@ QString DatInfo::getPlainBody( int num )
     QString bodytext;
     QString line = m_resDatVec[ num ].body;
 
-    ParseMisc::parseBODYdatText( PARSEMODE_TEXT, line, bodytext );
+    Kita::parseBODYdatText( PARSEMODE_TEXT, line, bodytext );
 
     return bodytext;
 }
@@ -528,7 +466,7 @@ QString DatInfo::getPlainTitle( int num )
 
     bool showAddr = KitaConfig::showMailAddress();
     QString titletext;
-    ParseMisc::parseTITLEdatText( PARSEMODE_TEXT, num, showAddr, m_resDatVec[ num ], titletext );
+    Kita::parseTITLEdatText( PARSEMODE_TEXT, num, showAddr, m_resDatVec[ num ], titletext );
 
     return titletext;
 }
@@ -551,7 +489,7 @@ QString DatInfo::getHtml( int startnum, int endnum )
         if ( !parseDat( num ) ) continue;
         if ( checkAbonePrivate( num ) ) retstr += aboneHTML( num );
         else if ( m_resDatVec[ num ].broken ) retstr += brokenHTML( num );
-        else retstr += ParseMisc::ResDatToHtml( m_resDatVec[ num ], num, showAddr );
+        else retstr += Kita::ResDatToHtml( m_resDatVec[ num ], num, showAddr );
     }
 
     return retstr;
@@ -569,7 +507,7 @@ QString DatInfo::getHtmlByID( const QString& strid, int &count )
 
     count = 0;
 
-    for ( int i = 1; i <= m_readNum; i++ ) {
+    for ( int i = 1; i <= m_thread->readNum(); i++ ) {
 
         if ( !parseDat( i ) ) continue;
 
@@ -577,7 +515,7 @@ QString DatInfo::getHtmlByID( const QString& strid, int &count )
             count ++;
             if ( checkAbonePrivate( i ) ) retstr += aboneHTML( i );
             else if ( m_resDatVec[ i ].broken ) retstr += brokenHTML( i );
-            else retstr += ParseMisc::ResDatToHtml( m_resDatVec[ i ], i, showAddr );
+            else retstr += Kita::ResDatToHtml( m_resDatVec[ i ], i, showAddr );
         }
     }
 
@@ -590,9 +528,9 @@ QString DatInfo::aboneHTML( int num )
 {
 
     QString tmpstr = QString( "<dl><dt>" );
-    tmpstr += QString().setNum( num ) + " " + ParseMisc::utf8ToUnicode( KITAUTF8_ABONE );
+    tmpstr += QString().setNum( num ) + " " + Kita::utf8ToUnicode( KITAUTF8_ABONE );
     tmpstr += "</dt><dd>";
-    tmpstr += ParseMisc::utf8ToUnicode( KITAUTF8_ABONE );;
+    tmpstr += Kita::utf8ToUnicode( KITAUTF8_ABONE );;
     tmpstr += "<br/><br/></dd></dl>";
 
     return tmpstr;
@@ -604,9 +542,9 @@ QString DatInfo::brokenHTML( int num )
 {
 
     QString tmpstr = QString( "<dl><dt>" );
-    tmpstr += QString().setNum( num ) + " " + ParseMisc::utf8ToUnicode( KITAUTF8_NAME );
+    tmpstr += QString().setNum( num ) + " " + Kita::utf8ToUnicode( KITAUTF8_NAME );
     tmpstr += "</dt><dd>";
-    tmpstr += ParseMisc::utf8ToUnicode( KITAUTF8_KOWARE );;
+    tmpstr += Kita::utf8ToUnicode( KITAUTF8_KOWARE );;
     tmpstr += "<br/><br/></dd></dl>";
 
     return tmpstr;
@@ -679,7 +617,7 @@ QString DatInfo::getTreeByResCore(
     if ( !reverse ) {
 
         /* collect responses that have anchor to rootnum */
-        for ( int i = rootnum + 1; i <= m_readNum; i++ ) {
+        for ( int i = rootnum + 1; i <= m_thread->readNum(); i++ ) {
             if ( checkAbonePrivate( i ) ) continue;
             if ( checkRes( i, rootnum ) ) {
                 count ++;
@@ -732,12 +670,14 @@ QString DatInfo::getTreeByResCore(
    then return TRUE.                            */  /* private */
 bool DatInfo::checkRes( const int num, const int target )
 {
+    const int range = 20;
     if ( ! parseDat( num ) ) return FALSE;
 
     setAncList( num );
     AncList& anclist = m_resDatVec[ num ].anclist;
 
     for ( AncList::iterator it = anclist.begin(); it != anclist.end(); ++it ) {
+        if( ( *it ).to - ( *it ).from > range ) continue;
         if ( target >= ( *it ).from && target <= ( *it ).to ) return TRUE;
     }
 
@@ -776,6 +716,7 @@ void DatInfo::setAncList( int num )
     QString line = m_resDatVec[ num ].body;
 
     /* remove HTML tags */
+    line.replace( "<br>", "\n" );
     QRegExp rex( "<[^>]*>" );
     line.remove( rex );
 
@@ -789,7 +730,7 @@ void DatInfo::setAncList( int num )
         if ( chpt[ i ].unicode() == UTF16_BRACKET ||  /* > */
                 ( chpt[ i ] == '&' && chpt[ i + 1 ] == 'g' && chpt[ i + 2 ] == 't' && chpt[ i + 3 ] == ';' )  /* "&gt;" */
            ) {
-            while ( ParseMisc::parseResAnchor( chpt + i, length - i, linkstr, refNum, pos ) ) {
+            while ( Kita::parseResAnchor( chpt + i, length - i, linkstr, refNum, pos ) ) {
                 if ( refNum[ 1 ] < refNum[ 0 ] ) refNum[ 1 ] = refNum[ 0 ];
                 anctmp.from = refNum[ 0 ];
                 anctmp.to = refNum[ 1 ];
@@ -807,7 +748,7 @@ void DatInfo::setAncList( int num )
     i = 0;
     length = line.length();
 
-    while ( ParseMisc::parseResAnchor( chpt + i, length - i, linkstr, refNum, pos ) ) {
+    while ( Kita::parseResAnchor( chpt + i, length - i, linkstr, refNum, pos ) ) {
         if ( refNum[ 1 ] < refNum[ 0 ] ) refNum[ 1 ] = refNum[ 0 ];
         anctmp.from = refNum[ 0 ];
         anctmp.to = refNum[ 1 ];
@@ -861,7 +802,7 @@ bool DatInfo::getDomElement(
         table = hdoc.createElement( "TABLE" );
         titlenode = table;
         tmpelm = table.insertRow( 0 );
-        ParseMisc::parseTITLEdat( PARSEMODE_DOM, hdoc, num, showAddr, resdat, tmpelm, tmpstr );
+        Kita::parseTITLEdat( PARSEMODE_DOM, hdoc, num, showAddr, resdat, tmpelm, tmpstr );
 
         /* body node */
         bodynode = hdoc.createElement( "DIV" );
@@ -876,7 +817,7 @@ bool DatInfo::getDomElement(
                 }
             }
 
-            ParseMisc::parseBODYdat( PARSEMODE_DOM, resdat.body, hdoc, showAA, bodynode, tmpstr );
+            Kita::parseBODYdat( PARSEMODE_DOM, resdat.body, hdoc, showAA, bodynode, tmpstr );
         }
 
     } else { /* abone or data is broken */
@@ -885,12 +826,12 @@ bool DatInfo::getDomElement(
         QString bodystr;
 
         if ( abone ) { /* "abone" node */
-            namestr = ParseMisc::utf8ToUnicode( KITAUTF8_ABONE );
-            bodystr = ParseMisc::utf8ToUnicode( KITAUTF8_ABONE );
+            namestr = Kita::utf8ToUnicode( KITAUTF8_ABONE );
+            bodystr = Kita::utf8ToUnicode( KITAUTF8_ABONE );
             status = "abone";
         } else { /* "broken" node */
-            namestr = ParseMisc::utf8ToUnicode( KITAUTF8_NAME );
-            bodystr = ParseMisc::utf8ToUnicode( KITAUTF8_KOWARE );
+            namestr = Kita::utf8ToUnicode( KITAUTF8_NAME );
+            bodystr = Kita::utf8ToUnicode( KITAUTF8_KOWARE );
             status = "broken";
         }
 
@@ -938,12 +879,21 @@ bool DatInfo::getDomElement(
 /*-----------------------*/
 /* several information */
 
+int DatInfo::getResNum()
+{
+    return m_thread->resNum();
+}
+
 /* public */
 int DatInfo::getReadNum()
 {
-    QMutexLocker locker( &m_mutex );
+    return m_thread->readNum();
+}
 
-    return m_readNum;
+/* public */
+int DatInfo::getViewPos()
+{
+    return m_thread->viewPos();
 }
 
 
@@ -955,7 +905,7 @@ int DatInfo::getNumByID( const QString& strid )
 
     int count = 0;
 
-    for ( int i = 1; i <= m_readNum; i++ ) {
+    for ( int i = 1; i <= m_thread->readNum(); i++ ) {
 
         if ( !parseDat( i ) ) continue;
         if ( checkAbonePrivate( i ) ) continue;
@@ -966,24 +916,6 @@ int DatInfo::getNumByID( const QString& strid )
     return count;
 }
 
-/* public */
-int DatInfo::getKokoyonNum()
-{
-    QMutexLocker locker( &m_mutex );
-
-    return QMIN( m_kokoyonNum, m_readNum );
-}
-
-/* public */
-void DatInfo::setKokoyonNum( int num )
-{
-    QMutexLocker locker( &m_mutex );
-
-    num = QMIN( num, m_readNum );
-
-    m_kokoyonNum = num;
-    KitaThreadInfo::setReadNum( m_datURL.prettyURL(), num );
-}
 
 /* public */
 int DatInfo::getDatSize()
@@ -1192,7 +1124,7 @@ bool DatInfo::checkAboneCore( const QString& str, QStringList& strlist )
 /* simple parsing function               */
 
 /* This function parses struct RESDAT by
-   ParseMisc::parseResDat. In short, this
+   Kita::parseResDat. In short, this
    splits the raw date into name, id,
    date, and bodytext, etc.
  
@@ -1207,13 +1139,10 @@ bool DatInfo::parseDat( int num )
     if ( num <= 0 || ( int ) m_resDatVec.size() <= num ) return FALSE;
     if ( m_resDatVec[ num ].parsed ) return TRUE;
 
-    QString tmpstr;
-    if ( !ParseMisc::parseResDat( m_resDatVec[ num ], tmpstr ) ) return FALSE;
-
-    /* get subject */
-    if ( m_subject == QString::null && tmpstr != QString::null ) {
-        m_subject = tmpstr;
-        Kita::Thread::setName( m_datURL.prettyURL(), m_subject );
+    QString subject = QString::null;
+    if ( !Kita::parseResDat( m_resDatVec[ num ], subject ) ) return FALSE;
+    if ( subject != QString::null && num == 1 ) {
+        m_thread->setThreadName( subject );
     }
 
     return TRUE;
