@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto , (c)2004 by 421                 *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -72,6 +72,7 @@ struct RESDAT
     QString address;
     QString body;
     QString id;
+    QString host;
     QString date;
     QDateTime dateTime;
 
@@ -106,20 +107,19 @@ namespace Kita
 
         QMutex m_mutex;
 
+	/* pointer of Thread class */
+	Thread* m_thread; 
+
         /* basic information */
-        int m_readNum;
         QString m_rawData;
         KURL m_datURL;
-        QString m_subject;
         bool m_broken;
         ResDatVec m_resDatVec;
         int m_lock;
-        int m_kokoyonNum; /* kokomade yonda */
 
         /* for caching */
         Access* m_access;
         OfflawAccess* m_access2;
-        Thread* m_thread;
         QString m_lastLine;
         bool m_nowLoading;
 
@@ -144,6 +144,7 @@ namespace Kita
         DatInfo( const KURL& url );
         ~DatInfo();
         void init();
+        void wait();	
         const KURL& url();
 
         /* for caching */
@@ -160,7 +161,6 @@ namespace Kita
         int isLocked();
 
         /* string data */
-        const QString& getSubject();
         const QString& getRawDat();
         const QString& getDat( int num );
         const QString& getId( int num );
@@ -180,10 +180,10 @@ namespace Kita
         bool getDomElement( int num, DOM::HTMLDocument& hdoc, DOM::Element& retelm );
 
         /* numerical data */
+        int getResNum();
         int getReadNum();
+	int getViewPos();
         int getNumByID( const QString& strid );
-        int getKokoyonNum();
-        void setKokoyonNum( int num );
         int getDatSize();
 
         /* several informations */
@@ -198,20 +198,19 @@ namespace Kita
         /* abone check */
         bool checkAbone( int num );
         void resetAbone();
-
+	
         /*-------------------------*/
 
     private:
 
-        void initPrivate();
+        void initPrivate( bool loadCache = TRUE );
         void resetResDat( RESDAT& resdat );
         void increaseResDatVec( int delta );
         void deleteAccessJob();
 
         /* copy data */
-        void copyRawDataToBuffer( const QString& rawData );
         bool copyOneLineToResDat( const QString& line, int num );
-
+	
         /* HTML data */
         QString aboneHTML( int num );
         QString brokenHTML( int num );
@@ -228,12 +227,11 @@ namespace Kita
         /* parsing funtions */
         bool parseDat( int num );
 
-        void updateThreadInfo();
         /*----------------------------*/
 
     private slots:
 
-        void slotReceiveData( const QString& newLine );
+        void slotReceiveData( const QStringList& lineList );
         void slotFinishLoad();
 
     signals:
