@@ -1,6 +1,6 @@
-/**************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto , (c)2004 by 421                 *
-*   ikemo@wakaba.jp                                                       *
+/***************************************************************************
+*   Copyright (C) 2004 by Kita Developers                                 *
+*   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -8,93 +8,45 @@
 *   (at your option) any later version.                                   *
 ***************************************************************************/
 
+/* DatManager manages all information about thread */
+
 #include <qobject.h>
 #include <qmutex.h>
 #include <qstringlist.h>
+#include <qregexp.h>
+#include <qfile.h>
 
 #include "thread.h"
 #include "threadinfo.h"
-#include "parsemisc.h"
 #include "datmanager.h"
 #include "datinfo.h"
-#include "board.h"
+#include "cache.h"
 #include "kita_misc.h"
 #include "kita-utf8.h"
 #include "kita-utf16.h"
+#include "threadindex.h"
+#include "boardmanager.h"
 
 using namespace Kita;
 
 #define DMANAGER_MAXQUEUE 16
 
-/*-------------------------------------------------*/
-/* DatManager manages all information about *.dat. */
-
-DatInfoList DatManager::m_datInfo;
+DatInfoList DatManager::m_datInfoList;
 QMutex DatManager::m_mutex;
 
-/* This function searches instance of DatInfo specified by url.
-   If instance does not exist, create instance.  */  /* private */
-DatInfo* DatManager::getDatInfo( const KURL& url )
+
+/*-----------------------------------------------------------------------*/
+
+
+/* create DatInfo explicitly.                    */
+/* Usually, DatInfo is NOT created
+   if cache does not exist( i.e. ReadNum == 0 ). */ /* public */
+bool DatManager::createDatInfo( const KURL& url )
 {
-    if ( url.isEmpty() ) {
-        return NULL;
-    }
-
-    int i = 0;
-    DatInfoList::Iterator it;
-    DatInfo* datInfo;
-
-    KURL inurl = Kita::ParseMisc::parseURLonly( url );
-
-    /* search */
-    if ( m_datInfo.count() ) {
-        for ( it = m_datInfo.begin(); it != m_datInfo.end(); ++it, i++ ) {
-
-            datInfo = ( *it );
-
-            if ( inurl == datInfo->url() ) {
-
-                /* LRU */
-                if ( i ) {
-                    m_datInfo.remove( it );
-                    m_datInfo.prepend( datInfo );
-                }
-
-                return datInfo;
-            }
-        }
-    }
-
-    /* not found */
-
-    /*create new DatInfo and insert it into list. */
-    KURL daturl = url.protocol() + "://" + url.host() + url.path();
-
-    datInfo = new DatInfo( daturl );
-    if ( datInfo->getRawDat() == QString::null ) { /* cache does not exist */
-        delete( datInfo );
-
-        return NULL;
-    }
-
-    m_datInfo.prepend( datInfo );
-
-    /* delete the last items of list */
-    if ( m_datInfo.count() > DMANAGER_MAXQUEUE ) {
-
-        /* collect unlocked datInfos */
-        typedef QValueList<KURL> DELETELIST;
-        DELETELIST deleteList;
-
-        for ( it = m_datInfo.at( DMANAGER_MAXQUEUE ); it != m_datInfo.end(); ++it )
-            if ( ! ( *it ) ->isLocked() ) deleteList += ( *it ) ->url();
-
-        /* delete unlocked datInfos */
-        for ( DELETELIST::Iterator itdel = deleteList.begin(); itdel != deleteList.end(); ++itdel )
-            deleteDatInfoPrivate( ( *itdel ) );
-    }
-
-    return datInfo;
+    if( getDatInfo( url,
+		    FALSE /* don't check the existence of cache */
+	    ) == NULL ) return FALSE;
+    return TRUE;
 }
 
 
@@ -105,65 +57,135 @@ DatInfo* DatManager::getDatInfo( const KURL& url )
 /* Usually, access to it through DatManager.           */ /* public */
 DatInfo * DatManager::getDatInfoPointer( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
     return getDatInfo( url );
 }
 
 
+/*------------------------------------------------------------------------*/
 
-/* public */
-void DatManager::deleteDatInfo( const KURL& url )
+
+/* This function searches instance of DatInfo in m_datInfoList.
+
+   If cache exists, create DatInfo and return its pointer.
+
+   If checkCached == TRUE and cache does not exist, return NULL.
+
+   If checkCached == FALSE and cache does not exist,
+   create DatInfo and return its pointer anyway.
+
+   see also DatManager::searchDatInfo() and DatManager::createDatInfo() */ /* private */
+
+DatInfo* DatManager::getDatInfo( const KURL& url, bool checkCached )
+{
+    /* search */
+    DatInfo* datInfo = searchDatInfo( url );
+    if( datInfo != NULL ) return datInfo;
+
+    /* create and enroll instance */
+    return enrollDatInfo( url, checkCached );
+}
+
+
+/* This function just searches instance of DatInfo specified by datURL
+   without creating instance.  */ /* private */
+DatInfo* DatManager::searchDatInfo( const KURL& url )
 {
     QMutexLocker locker( &m_mutex );
+    
+    KURL datURL = Kita::getDatURL( url );
+    if ( datURL.isEmpty() ) return NULL; /* This url is not enrolled in BoardManager. */
+    if ( m_datInfoList.count() == 0 ) return NULL;
 
-    deleteDatInfoPrivate( url );
-}
-
-
-/* private */
-void DatManager::deleteDatInfoPrivate( const KURL& url )
-{
-
+    int i = 0;
     DatInfoList::Iterator it;
+    DatInfo* datInfo;
+    
+    for ( it = m_datInfoList.begin(); it != m_datInfoList.end(); ++it, i++ ) {
 
-    for ( it = m_datInfo.begin(); it != m_datInfo.end(); ++it ) {
-        if ( url == ( *it ) ->url() ) {
+	datInfo = ( *it );
 
-            if ( ! ( *it ) ->isLocked() ) {
-                m_datInfo.remove( it );
-                delete( *it );
-            }
+	if ( datURL == datInfo->url() ) {
 
-            return ;
-        }
+	    /* LRU */
+	    if ( i ) {
+		m_datInfoList.remove( it );
+		m_datInfoList.prepend( datInfo );
+	    }
+
+	    return datInfo;
+	}
     }
 
+    return NULL;
 }
 
 
+/* create and enroll the instance of DatInfo and delete old instances. 
+   Note that DatInfo::DatInfo() opens cached data and reads it. */  /* private */
+DatInfo* DatManager::enrollDatInfo( const KURL& url, bool checkCached )
+{
+    QMutexLocker locker( &m_mutex );
+    
+    KURL datURL = Kita::getDatURL( url );
+    if( datURL.isEmpty() ) return NULL; /* This url is not enrolled in BoardManager. */
+
+    /* create DatInfo & read cached data */
+    DatInfo* datInfo = new DatInfo( datURL );
+
+    /* Does cache exist ? */
+    /* If cache does not exist, delete DatInfo here. */
+    if( checkCached && datInfo->getReadNum() == 0 ){
+	delete datInfo;
+	return NULL;
+    }
+
+    m_datInfoList.prepend( datInfo );
+
+    /* delete the all old instances ( LRU algorithm )*/
+    if ( m_datInfoList.count() > DMANAGER_MAXQUEUE ) {
+
+	DatInfoList::Iterator it;
+        for ( it = m_datInfoList.at( DMANAGER_MAXQUEUE ); it != m_datInfoList.end(); ++it ){
+
+	    if( ( *it ) == NULL ) continue;
+	    DatInfo* deleteInfo = ( *it );
+	    
+            if ( ! deleteInfo->isLocked() ){
+                m_datInfoList.remove( it );
+                --it;
+                deleteInfo->wait(); /* wait until DatInfo::m_mutex is released. */
+                delete deleteInfo;
+	    }
+	}
+    }
+
+    return datInfo;
+}
+
+
+/* public */
+void DatManager::deleteAllDatInfo()
+{
+    DatInfoList::Iterator it;
+    for ( it = m_datInfoList.begin(); it != m_datInfoList.end(); ++it ){
+
+	if( ( *it ) == NULL ) continue;
+	( *it )->wait();
+	delete ( *it );
+    }
+}
+
 
 
 /*-------------------------------------------------------------*/
 
 
 
-/*--------------------------------------*/
-/* update cache, then return new lines  */
-
-/* If cache does not exist, then create
-   the new instance.                    */ /* public */
+/* update cache */   /* public */
 bool DatManager::updateCache( const KURL& url , const QObject* parent )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
-
-    /* create new DatInfo */
-    if ( datInfo == NULL ) {
-        datInfo = new DatInfo( url );
-        m_datInfo.prepend( datInfo );
-    }
+    if ( datInfo == NULL ) return FALSE;
 
     return datInfo->updateCache( parent );
 }
@@ -172,8 +194,6 @@ bool DatManager::updateCache( const KURL& url , const QObject* parent )
 /* public */
 int DatManager::getResponseCode( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return 0;
 
@@ -183,8 +203,6 @@ int DatManager::getResponseCode( const KURL& url )
 /* public */
 int DatManager::getServerTime( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return 0;
 
@@ -195,21 +213,37 @@ int DatManager::getServerTime( const KURL& url )
 /* public */
 bool DatManager::deleteCache( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
+    KURL datURL = Kita::getDatURL( url );
+    Kita::Thread* thread = Kita::Thread::getByURLNew( datURL );
+    if( thread == NULL ) return FALSE;
+    if( thread->readNum() == 0 ) return FALSE;
 
-    DatInfo * datInfo = getDatInfo( url );
-    if ( datInfo == NULL ) return FALSE;
+    /* init DatInfo */
+    DatInfo * datInfo = searchDatInfo( datURL );
+    if( datInfo ){
+	if( !datInfo->deleteCache() ) return FALSE;
+    }
 
-    return datInfo->deleteCache();
+    /* reset readNum & veiwPos */
+    thread->setReadNum( 0 );
+    thread->setViewPos( 0 );
+
+    /* delete cache */
+    QString cachePath = Kita::Cache::getPath( datURL );
+    QString indexPath = Kita::Cache::getIndexPath( datURL );
+    QFile::remove( indexPath );
+    QFile::remove( cachePath );
+
+    /* delete log from "cache" */
+    KitaThreadInfo::removeThreadInfo( datURL.prettyURL() );
+    return TRUE;
 }
 
 
 /* public */
 bool DatManager::isLoadingNow( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
-    DatInfo * datInfo = getDatInfo( url );
+    DatInfo * datInfo = searchDatInfo( url );
     if ( datInfo == NULL ) return FALSE;
 
     return datInfo->isLoadingNow();
@@ -219,13 +253,7 @@ bool DatManager::isLoadingNow( const KURL& url )
 /* public */
 void DatManager::stopLoading( const KURL& url )
 {
-
-    /* Don't use QMutexLocker here !!
-       It will cause deadlock , because
-       Kita::Access::stopJob() calls KitaThreadView::slotFinishLoad() back.  */
-    m_mutex.lock();
-    DatInfo * datInfo = getDatInfo( url );
-    m_mutex.unlock();
+    DatInfo * datInfo = searchDatInfo( url );
     if ( datInfo == NULL ) return ;
 
     return datInfo->stopLoading();
@@ -236,31 +264,19 @@ void DatManager::stopLoading( const KURL& url )
 /*----------------------*/
 /* lock, unlock DatInfo */
 
-/* If cache does not exist, then create
-   the new instance and lock it. 
- 
-   Don't forget to unlock it. */  /* public */
-
-void DatManager::lock ( const KURL& url )
+/* public */
+void DatManager::lock( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
-
-    /* create new DatInfo */
-    if ( datInfo == NULL ) {
-        datInfo = new DatInfo( url );
-        m_datInfo.prepend( datInfo );
-    }
+    if( datInfo == NULL ) return;
 
     datInfo->lock ();
 }
 
+/* public */
 void DatManager::unlock( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
-    DatInfo * datInfo = getDatInfo( url );
+    DatInfo * datInfo = searchDatInfo( url );
     if ( datInfo == NULL ) return ;
 
     datInfo->unlock();
@@ -273,8 +289,6 @@ void DatManager::unlock( const KURL& url )
 /* public */
 const QString& DatManager::getRawDat( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -285,8 +299,6 @@ const QString& DatManager::getRawDat( const KURL& url )
 /* public */
 const QString& DatManager::getDat( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -298,8 +310,6 @@ const QString& DatManager::getDat( const KURL& url, int num )
 /* public */
 const QString& DatManager::getId( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -310,8 +320,6 @@ const QString& DatManager::getId( const KURL& url, int num )
 /* public */
 const QString& DatManager::getName( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -322,8 +330,6 @@ const QString& DatManager::getName( const KURL& url, int num )
 /* public */
 const QString& DatManager::getBody( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -334,8 +340,6 @@ const QString& DatManager::getBody( const KURL& url, int num )
 /* public */
 QString DatManager::getPlainName( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -346,8 +350,6 @@ QString DatManager::getPlainName( const KURL& url, int num )
 /* public */
 QString DatManager::getPlainBody( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -358,8 +360,6 @@ QString DatManager::getPlainBody( const KURL& url, int num )
 /* public */
 QString DatManager::getPlainTitle( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -367,85 +367,41 @@ QString DatManager::getPlainTitle( const KURL& url, int num )
 }
 
 
-/* get URL of thread from URL of dat file. */ /* public */
-const QString DatManager::threadURL( const KURL& url )
-{
-    QMutexLocker locker( &m_mutex );
-
-    KURL datURL = Kita::ParseMisc::parseURLonly( url );
-    return Kita::datToThread( datURL.prettyURL() );
-}
-
-
 /* get name (i.e. subject ) of thread from URL of dat file. */ /* public */
-const QString& DatManager::threadName( const KURL& url )
+const QString DatManager::threadName( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
-    KURL datURL = Kita::ParseMisc::parseURLonly( url );
+    KURL datURL = Kita::getDatURL( url );
     Kita::Thread* thread = Kita::Thread::getByURLNew( datURL );
+    if( thread != NULL ) return thread->threadName();
 
-    if ( thread == NULL ) {
-
-        /* get subject from DatInfo */
-        DatInfo * datInfo = getDatInfo( url );
-        if ( datInfo == NULL ) return QString::null;
-        return datInfo->getSubject();
-    }
-
-    return thread->name();
+    return QString::null;
 }
 
 
 /* public */
 const QString DatManager::threadID( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
-    KURL datURL = Kita::ParseMisc::parseURLonly( url );
+    KURL datURL = Kita::getDatURL( url );
     return datURL.filename().section( ".", 0, 0 );
 }
 
 
-/* get URL of board from URL of dat file. */ /* public */
-const QString DatManager::boardURL( const KURL& url )
+const QString DatManager::getCachePath( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
-    KURL datURL = Kita::ParseMisc::parseURLonly( url );
-    return Kita::datToBoard( datURL.prettyURL() );
+    return Kita::Cache::getPath( url );
 }
 
-
-/* get name of board from URL of dat file. */ /* public */
-const QString& DatManager::boardName( const KURL& url )
+const QString DatManager::getCacheIndexPath( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
-    KURL datURL = Kita::ParseMisc::parseURLonly( url );
-    QString bdURL = Kita::datToBoard( datURL.prettyURL() );
-    return Kita::Board::getName( bdURL );
+    return Kita::Cache::getIndexPath( url );
 }
 
-
-/* public */
-const QString DatManager::boardID( const KURL& url )
-{
-    QMutexLocker locker( &m_mutex );
-
-    KURL datURL = Kita::ParseMisc::parseURLonly( url );
-    return KURL( Kita::datToBoard( datURL.prettyURL() ) ).fileName();
-}
-
-
 /*---------------------------------------*/
 /* HTML data */
 
 /* public */
 QString DatManager::getHtml( const KURL& url, int startnum, int endnum )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -457,8 +413,6 @@ QString DatManager::getHtml( const KURL& url, int startnum, int endnum )
 /* public */
 QString DatManager::getHtmlByID( const KURL& url, const QString& strid, int &count )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo* datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -470,8 +424,6 @@ QString DatManager::getHtmlByID( const KURL& url, const QString& strid, int &cou
 /* Get HTML document of res tree.*/ /* public */
 QString DatManager::getTreeByRes( const KURL& url, const int rootnum, int &count )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo* datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -481,8 +433,6 @@ QString DatManager::getTreeByRes( const KURL& url, const int rootnum, int &count
 /* Get HTML document of reverse res tree.*/ /* public */
 QString DatManager::getTreeByResReverse( const KURL& url, const int rootnum, int &count )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo* datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return QString::null;
 
@@ -492,8 +442,6 @@ QString DatManager::getTreeByResReverse( const KURL& url, const int rootnum, int
 /* Get DOM element */ /* public */
 bool DatManager::getDomElement( const KURL& url, int num, DOM::HTMLDocument& hdoc, DOM::Element& retelm )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo* datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return FALSE;
 
@@ -501,69 +449,66 @@ bool DatManager::getDomElement( const KURL& url, int num, DOM::HTMLDocument& hdo
 }
 
 
-
 /* public */
 int DatManager::getResNum( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
+    KURL datURL = Kita::getDatURL( url );
+    Kita::Thread* thread = Kita::Thread::getByURLNew( datURL );
+    if( thread != NULL ) return thread->resNum();
 
-    KURL datURL = Kita::ParseMisc::parseURLonly( url );
-    return KitaThreadInfo::resNum( datURL.prettyURL() );
+    return 0;
 }
 
 
 /* public */
 int DatManager::getReadNum( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
+    KURL datURL = Kita::getDatURL( url );
+    Kita::Thread* thread = Kita::Thread::getByURLNew( datURL );
+    if( thread != NULL ) return thread->readNum();
 
-    DatInfo * datInfo = getDatInfo( url );
-    if ( datInfo == NULL ) return 0;
-
-    return datInfo->getReadNum();
+    return 0;
 }
 
 
 /* public */
-int DatManager::getKokoyonNum( const KURL& url )
+int DatManager::getViewPos( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
+    KURL datURL = Kita::getDatURL( url );
+    Kita::Thread* thread = Kita::Thread::getByURLNew( datURL );
+    if( thread != NULL ) return thread->viewPos();
 
-    DatInfo * datInfo = getDatInfo( url );
-    if ( datInfo == NULL ) return 0;
-
-    return datInfo->getKokoyonNum();
+    return 0;
 }
 
 
 /* public */
-void DatManager::setKokoyonNum( const KURL& url , int num )
+void DatManager::setViewPos( const KURL& url , int num )
 {
-    QMutexLocker locker( &m_mutex );
+    KURL datURL = Kita::getDatURL( url );
+    Kita::Thread* thread = Kita::Thread::getByURLNew( datURL );
+    if( thread != NULL ) thread->setViewPos( num );
 
-    DatInfo * datInfo = getDatInfo( url );
-    if ( datInfo == NULL ) return ;
+    /* save idx */
+    Kita::ThreadIndex::setViewPos( url, num );
 
-    return datInfo->setKokoyonNum( num );
+    /* save "cache" */
+    KitaThreadInfo::setReadNum( datURL.prettyURL(), num );
 }
 
 
 /* public */
 int DatManager::getDatSize( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return 0;
 
     return datInfo->getDatSize();
 }
 
-/* public */
+/* get number of responses which have same ID. */ /* public */
 int DatManager::getNumByID( const KURL& url, const QString& strid )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return 0;
 
@@ -571,11 +516,34 @@ int DatManager::getNumByID( const KURL& url, const QString& strid )
 }
 
 
+/* public */
+bool DatManager::isThreadEnrolled( const KURL& url )
+{
+    if( Kita::getDatURL( url ).isEmpty() ) return FALSE;
+
+    return TRUE;
+}
+
+
+/* public */
+bool DatManager::is2chThread( const KURL& url )
+{
+    if( BoardManager::type( url ) != Board_2ch ) return FALSE;
+    if( Kita::getDatURL( url ).isEmpty() ) return FALSE;
+    
+    QRegExp url_2ch( ".*\\.2ch\\.net" );
+    QRegExp url_bbspink( ".*\\.bbspink\\.com" );
+    
+    if ( url_2ch.search( url.host() ) != -1
+	 || url_bbspink.search( url.host() ) != -1 ) return TRUE;
+    
+    return FALSE;
+}
+
+
 /* public */
 bool DatManager::isResValid( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return FALSE;
 
@@ -586,8 +554,6 @@ bool DatManager::isResValid( const KURL& url, int num )
 /* public */
 bool DatManager::isBroken( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return FALSE;
 
@@ -597,8 +563,6 @@ bool DatManager::isBroken( const KURL& url )
 /* public */
 bool DatManager::isResBroken( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return FALSE;
 
@@ -607,11 +571,9 @@ bool DatManager::isResBroken( const KURL& url, int num )
 
 
 
-/* public */
+/* check if ID == strid  */ /* public */
 bool DatManager::checkID( const KURL& url, const QString& strid, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo* datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return FALSE;
 
@@ -619,14 +581,12 @@ bool DatManager::checkID( const KURL& url, const QString& strid, int num )
 }
 
 
-/* check keywords */ /* public */
+/* check if keywords are included */ /* public */
 bool DatManager::checkWord( const KURL& url,
                             QStringList& strlist, int num,
                             bool checkOR /* AND or OR search */
                           )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo* datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return FALSE;
 
@@ -637,8 +597,6 @@ bool DatManager::checkWord( const KURL& url,
 /* public */
 bool DatManager::isMarked( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return FALSE;
 
@@ -649,8 +607,6 @@ bool DatManager::isMarked( const KURL& url, int num )
 /* public */
 void DatManager::setMark( const KURL& url, int num, bool mark )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo * datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return ;
 
@@ -661,8 +617,6 @@ void DatManager::setMark( const KURL& url, int num, bool mark )
 /* public */
 bool DatManager::checkAbone( const KURL& url, int num )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo* datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return FALSE;
 
@@ -673,10 +627,37 @@ bool DatManager::checkAbone( const KURL& url, int num )
 /* public */
 void DatManager::resetAbone( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
-
     DatInfo* datInfo = getDatInfo( url );
     if ( datInfo == NULL ) return ;
 
     datInfo->resetAbone();
 }
+
+
+/* check if the thread is shown on the main thread tab. */ /* public */
+bool DatManager::isMainThreadOpened( const KURL& url )
+{
+    KURL datURL = Kita::getDatURL( url ).prettyURL();
+    Kita::Thread* thread = Kita::Thread::getByURLNew( datURL );
+    if( thread == NULL ) return FALSE;
+
+    return thread->isOpened();
+}
+
+void DatManager::setMainThreadOpened( const KURL& url, bool isOpened )
+{
+    KURL datURL = Kita::getDatURL( url ).prettyURL();
+    Kita::Thread* thread = Kita::Thread::getByURLNew( datURL );
+    if( thread != NULL ) thread->setIsOpened( isOpened );
+}
+
+
+/*--------------------------*/
+/* obsolete */
+
+/* public */
+const QString DatManager::threadURL( const KURL& url )
+{
+    return Kita::getThreadURL( url );
+}
+
