@@ -1,6 +1,6 @@
-/**************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto , (c)2004 by 421                 *
-*   ikemo@wakaba.jp                                                       *
+/***************************************************************************
+*   Copyright (C) 2004 by Kita Developers                                 *
+*   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -14,9 +14,9 @@
 #include <qvaluelist.h>
 
 class QMutex;
-class QStringList;
 class KURL;
 class QObject;
+class QStringList;
 
 namespace DOM
 {
@@ -32,13 +32,14 @@ namespace Kita
 
     class DatManager
     {
-        static DatInfoList m_datInfo;
+        static DatInfoList m_datInfoList;
         static QMutex m_mutex;
 
     public:
 
+        static bool createDatInfo( const KURL& url );
         static DatInfo* getDatInfoPointer( const KURL& url );
-        static void deleteDatInfo( const KURL& url );
+        static void deleteAllDatInfo();
 
         /* caching */
         static bool updateCache( const KURL& url , const QObject* parent );
@@ -63,14 +64,11 @@ namespace Kita
         static QString getPlainBody( const KURL& url, int num );
         static QString getPlainTitle( const KURL& url, int num );
 
-        static const QString threadURL( const KURL& url );
-        static const QString& threadName( const KURL& url ); /* = subject of thread */
+        static const QString threadName( const KURL& url ); /* = subject of thread */
         static const QString threadID( const KURL& url );
 
-        static const QString boardURL( const KURL& url );
-        static const QString& boardName( const KURL& url );
-        static const QString boardID( const KURL& url );
-
+        static const QString getCachePath( const KURL& url );
+        static const QString getCacheIndexPath( const KURL& url );
 
         /* HTML data */
         static QString getHtml( const KURL& url, int startnum, int endnum );
@@ -84,12 +82,15 @@ namespace Kita
         /* numerical data */
         static int getResNum( const KURL& url );
         static int getReadNum( const KURL& url );
-        static int getKokoyonNum( const KURL& url );
-        static void setKokoyonNum( const KURL& url, int num );
+        static int getViewPos( const KURL& url );
+        static void setViewPos( const KURL& url, int num );
         static int getDatSize( const KURL& url );
         static int getNumByID( const KURL& url, const QString& strid );
-
+	
+	
         /* another information */
+        static bool isThreadEnrolled( const KURL& url );
+        static bool is2chThread( const KURL& url );
         static bool isResValid( const KURL& url , int num );
         static bool isBroken( const KURL& url );
         static bool isResBroken( const KURL& url , int num );
@@ -103,18 +104,19 @@ namespace Kita
         static bool checkAbone( const KURL& url, int num );
         static void resetAbone( const KURL& url );
 
-        /* obsolete. Don't use them. */
-        static const QString thread_url( const KURL& url ) { return threadURL( url );}
-        static const QString& thread_name( const KURL& url ) { return threadName( url );}
-        static const QString thread_datID( const KURL& url ) { return threadID( url );}
-        static const QString thread_boardURL( const KURL& url ) { return boardURL( url );}
-        static const QString& thread_boardName( const KURL& url ) { return boardName( url );}
-        static const QString thread_boardID( const KURL& url ) { return boardID( url );}
+        /* check if the thread is shown on the main thread tab. */
+        static bool isMainThreadOpened( const KURL& url );
+        static void setMainThreadOpened( const KURL& url, bool isOpened );
 
+        /* obsolete. Don't use them. */
+	
+        static const QString threadURL( const KURL& url );
+	
     private:
 
-        static DatInfo* getDatInfo( const KURL& url );
-        static void deleteDatInfoPrivate( const KURL& url );
+        static DatInfo* getDatInfo( const KURL& url, bool checkCached = TRUE );
+        static DatInfo* searchDatInfo( const KURL& url );
+        static DatInfo* enrollDatInfo( const KURL& url, bool checkCached );
     };
 
 }
