@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto                                  *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -9,16 +9,17 @@
 ***************************************************************************/
 
 #include "favoritethreads.h"
+#include "thread.h"
+#include "threadindex.h"
+#include "boardmanager.h"
+#include "datmanager.h"
+#include "kita_misc.h"
 
 #include <kdebug.h>
 
 #include <qstylesheet.h>
 #include <qdom.h>
 
-#include "threadinfo.h"
-#include "board.h"
-#include "kita_misc.h"
-
 FavoriteThreads* FavoriteThreads::instance = 0;
 
 FavoriteThreads::FavoriteThreads()
@@ -89,46 +90,18 @@ void FavoriteThreads::processThreadNode( QDomNode& node )
 {
     QDomNode datURLNode = node.namedItem( "daturl" );
     QDomNode nameNode = node.namedItem( "name" );
-    QDomNode resNumNode = node.namedItem( "resnum" );
-    QDomNode boardNode = node.namedItem( "board" );
 
-    if ( !datURLNode.isElement() || !nameNode.isElement() ||
-            !resNumNode.isElement() || !boardNode.isElement() ) {
-        return ;
-    }
-    if ( boardNode.namespaceURI() != QString( "http://kita.sourceforge.jp/ns/board" ) ) {
-        return ;
-    }
-    if ( !processBoardNode( boardNode ) ) {
-        return ;
-    }
-    QString datURLText = datURLNode.toElement().text();
-    QString nameText = nameNode.toElement().text();
-    int resNum = resNumNode.toElement().text().toInt();
+    if ( !datURLNode.isElement() || !nameNode.isElement() ) return;
 
-    Kita::Thread::setName( datURLText, QStyleSheet::escape( nameText ) );
-    KitaThreadInfo::setResNum( datURLText, resNum );
+    QString url = datURLNode.toElement().text();
+    QString name = nameNode.toElement().text();
 
-    FavoriteThreads::getInstance() ->insert( datURLText );
-}
-
-bool FavoriteThreads::processBoardNode( QDomNode& node )
-{
-    QDomNode urlNode = node.namedItem( "url" );
-    QDomNode nameNode = node.namedItem( "name" );
-    if ( ! urlNode.isElement() || ! nameNode.isElement() ) {
-        return false;
-    }
-
-    QString urlText = urlNode.toElement().text();
-    QString nameText = nameNode.toElement().text();
-
-    KURL url = KURL( urlText );
-    if ( url.isValid() ) {
-        Kita::Board::setName( urlText, nameText );
-        return true;
-    }
-    return false;
+    KURL datURL = Kita::getDatURL( url );
+    Kita::Thread* thread = Kita::Thread::getByURL( datURL );
+    thread->setThreadName( name );
+    Kita::ThreadIndex::loadIndex( thread, datURL );
+    
+    FavoriteThreads::getInstance() ->insert( datURL.prettyURL() );
 }
 
 const QString FavoriteThreads::toXML() const
@@ -144,7 +117,6 @@ const QString FavoriteThreads::toXML() const
     QValueList<QString>::const_iterator it;
     for ( it = threadList().begin(); it != threadList().end(); ++it ) {
         QString datURL = ( *it );
-        const Kita::Thread* thread = Kita::Thread::getByURL( *it );
         QDomElement threadElement = document.createElementNS( "http://kita.sourceforge.jp/ns/thread", "thread" );
         root.appendChild( threadElement );
 
@@ -152,28 +124,28 @@ const QString FavoriteThreads::toXML() const
         threadElement.appendChild( datURLElement );
         datURLElement.appendChild( document.createTextNode( datURL ) );
 
-        QString threadName = thread->name();
+        QString threadName = Kita::DatManager::threadName( datURL );
         QDomElement nameElement = document.createElement( "name" );
         threadElement.appendChild( nameElement );
-        nameElement.appendChild( document.createTextNode( Kita::unescape( threadName ) ) );
+        nameElement.appendChild( document.createTextNode( threadName ) );
+  	 
+        QString resNum = QString::number( Kita::DatManager::getResNum( datURL ) ); 	 
+        QDomElement resNumElement = document.createElement( "resnum" ); 	 
+        threadElement.appendChild( resNumElement ); 	 
+        resNumElement.appendChild( document.createTextNode( resNum ) ); 	 
+  	 
+        // board 	 
+        QDomElement board = document.createElementNS( "http://kita.sourceforge.jp/ns/board", "board" );   
+        threadElement.appendChild( board ); 	 
 
-        QString resNum = QString::number( KitaThreadInfo::resNum( datURL ) );
-        QDomElement resNumElement = document.createElement( "resnum" );
-        threadElement.appendChild( resNumElement );
-        resNumElement.appendChild( document.createTextNode( resNum ) );
+        QString boardURL = Kita::BoardManager::boardURL( datURL ); 	 
+        QDomElement boardURLElement = document.createElement( "url" ); 	 
+        board.appendChild( boardURLElement ); 	 
+        boardURLElement.appendChild( document.createTextNode( boardURL ) ); 	 
 
-        // board
-        QDomElement board = document.createElementNS( "http://kita.sourceforge.jp/ns/board", "board" );
-        threadElement.appendChild( board );
-
-        QString boardURL = Kita::datToBoard( datURL );
-        QDomElement boardURLElement = document.createElement( "url" );
-        board.appendChild( boardURLElement );
-        boardURLElement.appendChild( document.createTextNode( boardURL ) );
-
-        QString boardName = Kita::Board::getName( boardURL );
-        QDomElement boardNameElement = document.createElement( "name" );
-        board.appendChild( boardNameElement );
+        QString boardName = Kita::BoardManager::boardName( boardURL ); 	 
+        QDomElement boardNameElement = document.createElement( "name" ); 	 
+        board.appendChild( boardNameElement ); 	 
         boardNameElement.appendChild( document.createTextNode( boardName ) );
     }
     return document.toString( 0 );
@@ -181,6 +153,7 @@ const QString FavoriteThreads::toXML() const
 
 void FavoriteThreads::replace( QString fromURL, QString toURL )
 {
+    if( FavoriteThreads::getInstance() == NULL ) return;
     QValueList<QString>& threadList = FavoriteThreads::getInstance() ->m_threadList;
     QValueList<QString>::iterator it;
     for ( it = threadList.begin(); it != threadList.end(); ++it ) {
