@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto                                  *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -18,8 +18,6 @@
 #include <qptrlist.h>
 #include <qdict.h>
 
-#include "thread.h"
-
 class QDomNode;
 
 /**
@@ -40,7 +38,6 @@ public:
     const QString toXML() const;
     static bool readFromXML( const QString& xml );
     static void processThreadNode( QDomNode& node );
-    static bool processBoardNode( QDomNode& node );
     static void replace( QString fromURL, QString toURL );
 };
 
