@@ -1,22 +1,21 @@
-/**************************************************************************
-*   Copyright (C) 2003,2004 by Hideki Ikemoto , (c) 2004 by 421           *
-*   ikemo@wakaba.jp                                                       *
+/***************************************************************************
+*   Copyright (C) 2004 by Kita Developers                                 *
+*   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
-**************************************************************************/
+***************************************************************************/
 
 /* Image Manager class */
 
 #include "imgmanager.h"
 #include "cache.h"
 #include "kitaconfig.h"
+#include "downloadmanager.h"
 
-#include <kurl.h>
 #include <kdeversion.h>
-#include <kio/job.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
 #include <kfiledialog.h>
@@ -39,22 +38,14 @@ QMutex ImgManager::m_mutex;
 
 ImgManager::ImgManager( QWidget* mainwidget )
 {
-    m_loaderList.clear();
     m_imgDatDict.clear();
     m_mainwidget = mainwidget;
+    m_urlList.clear();
 }
 
 
 ImgManager::~ImgManager()
-{
-    /* delete all loaders */
-    FileLoader * loader;
-    QPtrListIterator< FileLoader > it( m_loaderList );
-    while ( ( loader = it.current() ) != NULL ) {
-        delete loader;
-        ++it;
-    }
-}
+{}
 
 
 /* call this first */ /* public */ /* static */
@@ -81,8 +72,6 @@ ImgManager* ImgManager::getInstance()
 /* public */ /* static */
 bool ImgManager::isImgFile( const KURL& url, bool use_mimetype )
 {
-    QMutexLocker locker( &m_mutex );
-
     return instance->isImgFilePrivate( url, use_mimetype );
 }
 
@@ -121,7 +110,7 @@ void ImgManager::stop( const KURL& url )
 {
     QMutexLocker locker( &m_mutex );
 
-    instance->stopPrivate( url );
+    DownloadManager::stopLoading( url );
 }
 
 
@@ -135,9 +124,8 @@ QString ImgManager::getPath( const KURL& url )
 /* public */ /* static */
 bool ImgManager::isLoadingNow( const KURL& url )
 {
-    QMutexLocker locker( &m_mutex );
 
-    return instance->isLoadingNowPrivate( url );
+    return DownloadManager::isLoadingNow( url );
 }
 
 
@@ -303,11 +291,11 @@ bool ImgManager::isImgFilePrivate( const KURL& url, bool use_mimetype )
 /* when done, ImgManager emits finishImgLoad SIGNAL.   */   /* private */
 bool ImgManager::loadPrivate( const KURL& url, const KURL& datURL )
 {
-    const unsigned int maxload = 5; // = KitaConfig::maxImgLoader();
+    const unsigned int maxload = 5; // = KitaConfig::maxLoader();
 
-    /*-----------------------------------------*/
-
-    if ( isLoadingNowPrivate( url ) ) return FALSE;
+    /*------------------------------*/
+    
+    if ( DownloadManager::isLoadingNow( url ) ) return FALSE;
 
     /* cache exists? */
     if ( cacheExists( url ) ) {
@@ -320,62 +308,30 @@ bool ImgManager::loadPrivate( const KURL& url, const KURL& datURL )
         return TRUE;
     }
 
-    if ( m_loaderList.count() >= maxload ) return FALSE;
-
-    /* create directry of cache */
+    if( m_urlList.count() > maxload ) return FALSE;
+    
     QString path = Cache::getImgPath( url );
-    KURL cacheDir = KURL( path, "." );
-    KURL cacheDir2 = KURL( cacheDir, ".." );
-#if KDE_IS_VERSION( 3, 2, 0 )
-    if ( !KIO::NetAccess::exists( cacheDir2, TRUE, m_mainwidget ) ) KIO::NetAccess::mkdir( cacheDir2, m_mainwidget );
-    if ( !KIO::NetAccess::exists( cacheDir, TRUE, m_mainwidget ) ) KIO::NetAccess::mkdir( cacheDir, m_mainwidget );
-#else
-    if ( !KIO::NetAccess::exists( cacheDir2 ) ) KIO::NetAccess::mkdir( cacheDir2 );
-    if ( !KIO::NetAccess::exists( cacheDir ) ) KIO::NetAccess::mkdir( cacheDir );
-#endif
-
     deleteImgDat( url );
 
     /* create new loader, and start loading the file */
     /* slotResult is called when done.               */
-    FileLoader* loader = new FileLoader( url, datURL, path );
-    if ( loader->get() ) {
-        m_loaderList.append( loader );
+    LoaderOption option;
+    option.usrurl = datURL;
+    FileLoader* loader = DownloadManager::download( url, path, option );
+    if ( loader == NULL ) return FALSE;
+    
+    connect( loader, SIGNAL( data( const Kita::LoaderData&, const QByteArray& ) ),
+	     SLOT( slotData( const Kita::LoaderData&, const QByteArray& ) ) );
 
-        connect( loader, SIGNAL( data( Kita::FileLoader*, const QByteArray& ) ),
-                 SLOT( slotData( Kita::FileLoader*, const QByteArray& ) ) );
+    connect( loader, SIGNAL( result( const Kita::LoaderData& ) ),
+	     SLOT( slotResult( const Kita::LoaderData& ) ) );
 
-        connect( loader, SIGNAL( result( Kita::FileLoader* ) ),
-                 SLOT( slotResult( Kita::FileLoader* ) ) );
-    }
-    else {
-        deleteLoader( loader );
-        return FALSE;
-    }
+    m_urlList += url.prettyURL();
 
     return TRUE;
 }
 
 
-/* stop loading */  /* private */
-void ImgManager::stopPrivate( const KURL& url )
-{
-    FileLoader * loader = getLoader( url );
-    if ( !loader ) return ;
-
-    loader->stopJob(); /* slotResult() will be called later. */
-}
-
-
-/* private */
-bool ImgManager::isLoadingNowPrivate( const KURL& url )
-{
-    if ( getLoader( url ) ) return TRUE;
-
-    return FALSE;
-}
-
-
 /* delete cache */
 /* when done, cacheDeleted SIGNAL emitted */ /* private */
 bool ImgManager::deleteCachePrivate( const KURL& url, QWidget* parent )
@@ -483,37 +439,6 @@ void ImgManager::setMosaicPrivate( const KURL& url, bool status )
 }
 
 
-/* get loader from url */ /* private */
-FileLoader* ImgManager::getLoader( const KURL& url )
-{
-    if ( m_loaderList.count() == 0 ) return NULL;
-
-    FileLoader* loader;
-    QPtrListIterator< FileLoader > it( m_loaderList );
-    while ( ( loader = it.current() ) != NULL ) {
-
-        if ( loader->url() == url ) {
-            return loader;
-        }
-        ++it;
-    }
-
-    return NULL;
-}
-
-
-/* delete loader */ /* private */
-void ImgManager::deleteLoader( FileLoader* loader )
-{
-    /* Deleting the FileLoader in the call-backed
-       functions ( e.g. slotResult() ) causes many
-       problems. Maybe kita will crush.  So,
-       delete it later.  See also customEvent().    */
-    DeleteLoaderEvent * e = new DeleteLoaderEvent( loader );
-    QApplication::postEvent( this, e );  // Qt will delete it when done
-}
-
-
 /* private */
 void ImgManager::createImgDat( const KURL& url, int code )
 {
@@ -580,7 +505,7 @@ void ImgManager::getSize( const KURL& url )
 /* private */
 bool ImgManager::cacheExists( const KURL& url )
 {
-    if ( isLoadingNowPrivate( url ) ) return FALSE;
+    if ( DownloadManager::isLoadingNow( url ) ) return FALSE;
 
     bool ret;
     QString path = Cache::getImgPath( url );
@@ -599,270 +524,50 @@ bool ImgManager::cacheExists( const KURL& url )
 
 
 /* This slot is called when loader received the data. */ /* private slot */
-void ImgManager::slotData( Kita::FileLoader* loader, const QByteArray& barray )
+void ImgManager::slotData( const Kita::LoaderData& data, const QByteArray& barray )
 {
     /* check BMP header */
-    if ( barray.size() > 2 && loader->size() == barray.size()
+    if ( barray.size() > 2 && data.size == barray.size()
             && barray[ 0 ] == 'B' && barray[ 1 ] == 'M' ) {
-        loader->stopJob();
+        DownloadManager::stopLoading( data.url );
         return ;
     }
 
     /* I assume that file size is smaller than 2^32 byte */
-    unsigned int size = loader->size();
-    unsigned int totalsize = loader->totalsize();
-
-    emit receiveImgData( loader->url(), size, totalsize );
+    emit receiveImgData( data.url, data.size, data.totalsize );
 }
 
 
 /* This slot is called when loading is done. */ /* private slot */
-void ImgManager::slotResult( Kita::FileLoader* loader )
+void ImgManager::slotResult( const Kita::LoaderData& data )
 {
-    createImgDat( loader->url(), loader->code() );
-    m_loaderList.remove( loader );
+    m_urlList.remove( data.url.prettyURL() );
+    createImgDat( data.url, data.code );
 
     /* save size, datURL, etc */
-    if ( loader->code() == 200 ) {
-        unsigned int totalsize = loader->totalsize();
-        KURL datURL = loader->datURL();
-        KConfig cfg( Cache::getImgIdxPath( loader->url() ) );
+    if ( data.code == 200 ) {
+        unsigned int totalsize = data.totalsize;
+        KURL datURL = data.option.usrurl;
+        KConfig cfg( Cache::getImgIdxPath( data.url ) );
         cfg.writeEntry( "Size", totalsize );
         cfg.writeEntry( "datURL", datURL.prettyURL() );
-        IMGDAT* imgdat = instance->getImgDat( loader->url() );
+        IMGDAT* imgdat = instance->getImgDat( data.url );
         imgdat->size = totalsize;
         imgdat->datURL = datURL;
     }
 
-    emit finishImgLoad( loader->url() );
-
-    deleteLoader( loader );
+    emit finishImgLoad( data.url );
 }
 
 
 /* protected */ /* virtual */
 void ImgManager::customEvent( QCustomEvent * e )
 {
-    /* delete loader */
-    if ( e->type() == EVENT_DeleteLoader ) {
-        FileLoader * loader = static_cast< DeleteLoaderEvent* >( e ) ->getLoader();
-        if ( loader ) {
-
-            m_loaderList.remove( loader );
-
-            /* error file is also deleted here. */
-            if ( loader->code() != 200 ) KIO::del( loader->path(), FALSE, FALSE );
-
-            delete loader;
-        }
-    }
-
     /* emit finishImgLoad SIGNAL */
-    else if ( e->type() == EVENT_EmitFinigh ) {
+    if ( e->type() == EVENT_EmitFinigh ) {
         KURL url = static_cast< EmitFinishEvent* >( e ) ->url();
         emit finishImgLoad( url );
     }
 }
 
 
-
-/*-----------------------------------------------------------*/
-/*-----------------------------------------------------------*/
-/*-----------------------------------------------------------*/
-
-
-
-FileLoader::FileLoader( const KURL& url,
-                        const KURL& datURL,
-                        const QString& path
-                      )
-{
-    m_url = url;
-    m_datURL = datURL;
-    m_path = path;
-
-    m_ds = NULL;
-    m_file = NULL;
-    m_totalsize = 0;
-    m_size = 0;
-
-    m_code = 0;
-    m_currentJob = NULL;
-    m_header = QString::null;
-}
-
-FileLoader::~FileLoader()
-{
-    killJob();
-}
-
-
-/* terminate job. */ /* public */
-void FileLoader::killJob()
-{
-    if ( m_currentJob == NULL ) return ;
-
-    m_currentJob->kill(); /* without emitting result SIGNAL */
-    m_currentJob = NULL;
-    m_code = 0;
-    closeFile();
-}
-
-
-/* stop job. slotResult is called later. */ /* public */
-void FileLoader::stopJob()
-{
-    if ( m_currentJob ) m_currentJob->kill( FALSE ); /* with emitting result SIGNL */
-}
-
-
-/* start downloading                              */
-/* When done, signal loadFinished is emitted.     */ /* public */
-bool FileLoader::get()
-{
-    /* now loading */
-    if ( m_currentJob ) return FALSE;
-
-    m_totalsize = 0;
-    m_size = 0;
-    m_code = 0;
-    m_header = QString::null;
-
-    /* open file */
-    m_file = new QFile( m_path );
-    if ( m_file == NULL || ! m_file->open( IO_WriteOnly ) ) {
-        closeFile();
-        return FALSE;
-    }
-    m_ds = new QDataStream( m_file );
-
-    /* create job */
-    m_currentJob = KIO::get( m_url, TRUE, FALSE );
-    if ( m_currentJob == NULL ) {
-        closeFile();
-        return FALSE;
-    }
-
-    connect( m_currentJob, SIGNAL( data( KIO::Job*, const QByteArray& ) ),
-             SLOT( slotData( KIO::Job*, const QByteArray& ) ) );
-
-    connect( m_currentJob, SIGNAL( result( KIO::Job* ) ),
-             SLOT( slotResult( KIO::Job* ) ) );
-
-    connect( m_currentJob, SIGNAL( redirection( KIO::Job *, const KURL& ) ),
-             SLOT( slotRedirection( KIO::Job *, const KURL& ) ) );
-
-    connect( m_currentJob, SIGNAL( totalSize( KIO::Job*, KIO::filesize_t ) ),
-             SLOT( slotTotalSize( KIO::Job*, KIO::filesize_t ) ) );
-
-    /* use 'HTTP-Headers' metadata.*/
-    m_currentJob->addMetaData( "PropagateHttpHeader", "true" );
-
-    return TRUE;
-}
-
-/* public */
-const bool FileLoader::isRunning() const
-{
-    if ( m_currentJob ) return TRUE;
-    return FALSE;
-}
-
-/* public */
-const int FileLoader::code() const
-{
-    return m_code;
-}
-
-/* public */
-const KURL FileLoader::url() const
-{
-    return m_url;
-}
-
-/* public */
-const QString FileLoader::path() const
-{
-    return m_path;
-}
-
-/* public */
-const KIO::filesize_t FileLoader::size() const
-{
-    return m_size;
-}
-
-/* public */
-const KIO::filesize_t FileLoader::totalsize() const
-{
-    return m_totalsize;
-}
-
-/* public */
-const KURL FileLoader::datURL() const
-{
-    return m_datURL;
-}
-
-/* private */
-void FileLoader::closeFile()
-{
-    if ( m_file ) m_file->close();
-    if ( m_ds ) delete m_ds;
-    if ( m_file ) delete m_file;
-
-    m_ds = NULL;
-    m_file = NULL;
-}
-
-/* private */ /* copied from Access::responseCode() */
-int FileLoader::responseCode()
-{
-    // parse HTTP headers
-    QStringList headerList = QStringList::split( "\n", m_header );
-    QRegExp regexp( "HTTP/1\\.[01] ([0-9]+) .*" );
-    QString dateStr = headerList.grep( regexp ) [ 0 ];
-    if ( regexp.search( dateStr ) == -1 ) {
-        // invalid response
-        return 0;
-    } else {
-        return regexp.cap( 1 ).toInt();
-    }
-}
-
-
-/* slots called from job */ /* private slots */
-
-void FileLoader::slotData( KIO::Job* job, const QByteArray& barray )
-{
-    if ( job->error() == 0 ) {
-
-        m_size += barray.size();
-        m_ds->writeRawBytes( barray.data(), barray.size() );
-
-        emit data( this, barray );
-    }
-}
-
-
-void FileLoader::slotTotalSize( KIO::Job * job, KIO::filesize_t size )
-{
-    if ( job->error() == 0 ) m_totalsize = size;
-}
-
-
-void FileLoader::slotRedirection( KIO::Job*, const KURL& )
-{
-    stopJob();
-}
-
-
-void FileLoader::slotResult( KIO::Job* job )
-{
-    m_currentJob = NULL;
-    if ( job->error() == 0 ) m_header = job->queryMetaData( "HTTP-Headers" );
-    m_code = responseCode();
-    closeFile();
-
-    emit result( this );
-}
