@@ -20,52 +20,23 @@
 #include <klocale.h>
 #include <kdebug.h>
 
-#include "qcp932codec.h"
 #include "parsemisc.h"
 #include "datinfo.h"  /* struct RESDAT is defined. */
 #include "kita-utf8.h"
 #include "kita-utf16.h"
+#include "boardmanager.h"
+#include "kita_misc.h"
 
 #define KITA_RESDIGIT 4
 
 using namespace Kita;
 
 
-/*---------------------------------------------------*/
-
-/* Text codec */
-
-QCp932Codec* ParseMisc::m_qcpCodec = NULL;
-QTextCodec* ParseMisc::m_utf8Codec = NULL;
-QMutex ParseMisc:: m_codexMutex;
 QString ParseMisc::m_weekstr[ 7 ];
 QString ParseMisc::m_colonstr;
 QString ParseMisc::m_colonnamestr;
 
 
-QString ParseMisc::qcpToUnicode( const QString& str )
-{
-
-    QMutexLocker locker( & m_codexMutex ); /* QTextCodec is not reentrant. */
-
-    if ( !m_qcpCodec ) m_qcpCodec = new QCp932Codec();
-
-    return m_qcpCodec->toUnicode( str );
-}
-
-
-QString ParseMisc::utf8ToUnicode( const QString& str )
-{
-
-    QMutexLocker locker( & m_codexMutex ); /* QTextCodec is not reentrant. */
-
-    if ( !m_utf8Codec ) m_utf8Codec = QTextCodec::codecForName( "utf8" );
-
-    return m_utf8Codec->toUnicode( str );
-}
-
-
-
 /*------------------------------------------------------------*/
 /*------------------------------------------------------------*/
 
@@ -82,7 +53,7 @@ QString ParseMisc::utf8ToUnicode( const QString& str )
 /*
   struct RESDAT resdat should be parsed by parseResDat before
   calling this function. struct RESDAT is defined in datinfo.h
- 
+
   If mode = PARSEMODE_DOM, titlenode is DOM tree of title node.
   titletext is ignored.
  
@@ -1078,82 +1049,125 @@ bool ParseMisc::parseLink(
 
 
 
-/*----------------------------------------------------------*/
-/* parse URL to get correct URL of dat file.
- 
+
+/* convert thread URL, and get reference. 
+   if mode = 0, output is URL of dat file. If mode = 1, output is URL of read.cgi .
+
 (ex.1)
- 
-http://pc5.2ch.net/linux/dat/1069738960.dat#20-30
- 
+
+mode = 0
+url  = http://pc5.2ch.net/linux/dat/1069738960.dat#20-30
 ->
- 
-newURL = http://pc5.2ch.net/linux/dat/1069738960.dat
-retstr = 20-30
- 
+return : http://pc5.2ch.net/linux/dat/1069738960.dat
+retstr : 20-30
+
 (ex.2)
- 
- 
-http://pc5.2ch.net/test/read.cgi/linux/1069738960/-100
- 
+
+mode = 1
+url  = http://pc5.2ch.net/linux/dat/1069738960.dat#20-30
 ->
- 
-newURL = http://pc5.2ch.net/linux/dat/1069738960.dat
-refstr = 1-100                                                */ /* public */
+return : http://pc5.2ch.net/test/read.cgi/linux/1069738960
+retstr : 20-30
 
-KURL ParseMisc::parseURL( const KURL& url , QString& refstr )
+(ex.3)
+
+mode = 0
+url  = http://pc5.2ch.net/test/read.cgi/linux/1069738960/-100
+->
+return : http://pc5.2ch.net/linux/dat/1069738960.dat
+refstr : 1-100
+                                                            */ /* public */
+
+QString ParseMisc::convertURL( int mode, /* if 0, output is dat URL. If 1, output is thread URL */
+			    const KURL& url , QString& refstr )
 {
-    KURL newURL = url;
-    QString root;
-    QString board;
-    QString thread;
-    QString refBase;
-    refstr = QString::null;
+    /* Is board enrolled ? */
+    BoardData* bdata = Kita::BoardManager::getBoardData( url );
+    if( bdata == NULL ) return url.prettyURL();
 
-    if ( url.path().contains( "/read.cgi" ) ) {
+    QString urlstr = url.prettyURL();
 
-        if ( url.path().contains( "/test/read.cgi" ) )    /* 2ch */
-            root = url.prettyURL().section( "/test/read.cgi", 0, 0 );
-        else root = url.prettyURL().section( "/read.cgi", 0, 0 );
+    /* get thread & reference */
+    QString thread = QString::null;
+    QString refBase = QString::null;;
 
-        QString tmp = url.path().section( "/read.cgi", 1 );
+    if( urlstr.contains( "/dat/" ) ){ 
 
-        board = tmp.section( '/', 1, 1 );
-        thread = tmp.section( '/', 2, 2 );
-        refBase = tmp.section( '/', 3, 3 );
+	/* url = (hostname)/(rootPath)/(bbsPath)/dat/(thread_ID).(ext)#(refBase)  */
+	thread = url.filename().remove( bdata->ext() );
+	refBase = url.ref();
+    }
+    else if( urlstr.contains( bdata->delimiter() ) ) {
 
-        QRegExp reg( "\\d+" );
-        if ( reg.exactMatch( thread ) ) {
+	QString tmpstr;
+	switch( bdata->type() ){
 
-            QString newPath = QString( "/%1/dat/%2.dat" ).arg( board ).arg( thread );
+        /* url = (hostname)/(rootPath)/(delimiter)/(bbsPath)/(thread_ID)/(refBase) */
+	case Board_2ch:
+	case Board_JBBS:
+	    tmpstr = urlstr.section( bdata->delimiter() + bdata->bbsPath(), 1, 1 );
+            thread = tmpstr.section( '/', 1, 1 );
+	    refBase = tmpstr.section( '/', 2, 2 );
+	    break;
 
-            newURL = root + newPath;
-
-            if ( ! refBase.isEmpty() ) {
-                if ( refBase.at( 0 ) == '-' ) refstr = "1" + refBase;
-                else refstr = refBase;
-            }
-
-            return newURL;
-        }
+	/* machi BBS */
+	/* ex.) If url = http://kanto.machi.to/bbs/read.pl?BBS=kana&KEY=1096716679 ,
+	   then, thread = 1096716679                                */
+	case Board_MachiBBS:
+	    thread = url.queryItem( "KEY" );
+	    refBase = QString::null;
+	    break;
+	}
     }
 
-    if ( newURL.hasRef() ) {
-        refstr = newURL.ref();
-        newURL = newURL.protocol() + "://" + newURL.host() + newURL.path();
+    if( thread == QString::null ){
+	if( mode == 0 )	return bdata->basePath();
+	return bdata->cgiBasePath();
     }
 
+    if ( refBase != QString::null ){
+	
+	if ( refBase.at( 0 ) == '-' ) refstr = "1" + refBase;
+	else refstr = refBase;
+    }
 
-    kdDebug() << "newURL: " << newURL.url() << endl;
+    /* create new URL */
+    QString newURL;
+    if( mode == 0 ) newURL = bdata->basePath() + "dat/" + thread + bdata->ext();
+    else {
+	newURL = bdata->cgiBasePath();
+	    
+	switch( bdata->type() ){
+	case Board_2ch:
+	case Board_JBBS:
+	    newURL += thread;
+	    break;
+
+	case Board_MachiBBS:
+	    newURL += "&KEY=" + thread;
+	    break;
+	}
+    }
+/*
+    qDebug( "convertURL (mode %d)", mode );
+    qDebug( "input  = %s", url.prettyURL().ascii() );
+    qDebug( "output = %s", newURL.ascii() );    
+    qDebug( "thread = %s", thread.ascii() );
+    qDebug( "ref = %s", refBase.ascii() );    
+*/
     return newURL;
 }
 
+KURL ParseMisc::parseURL( const KURL& url , QString& refstr )
+{
+    return convertURL( 0, url, refstr );
+}
 
 /* for convenience */
 KURL ParseMisc::parseURLonly( const KURL& url )
 {
     QString refstr;
-
-    return parseURL( url, refstr );
+    return convertURL( 0, url, refstr );
 }
 
 
@@ -1250,3 +1264,20 @@ bool ParseMisc::createResAnchor(
 
 
 
+
+/*---------------------------------------------*/
+
+/* obsolete */
+
+
+QString ParseMisc::qcpToUnicode( const QString& str )
+{
+    return Kita::qcpToUnicode( str );
+}
+
+
+QString ParseMisc::utf8ToUnicode( const QString& str )
+{
+    return Kita::utf8ToUnicode( str );
+}
+
