@@ -96,12 +96,8 @@ namespace Kita
         /* to : KitaSubjectView, FavoriteListView */
         void updateSubjectTab( const KURL& url );
 
-        /* to : KitaSubjectTabWidget */
-        void switchSubjectView();
-
         /* to: KitaSubjectDock */
         void switchToSubject();
-        void openBoardRequested( const QString& boardURL, bool withNewTab );
 
         /*--------------------------------*/
 
@@ -122,7 +118,8 @@ namespace Kita
         void closeWriteTab( const KURL& url );
 
         /* to : KitaWriteDock */
-        void showWriteView( const KURL& , const QString&, const QString& );
+        void showWriteView( const KURL& , const QString& );
+        void createNewThread( const KURL& , const QString&, const QString& );	
         void switchToWritedock();
     };
 
