@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto                                  *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -10,83 +10,110 @@
 
 #include "thread.h"
 
-#include <config.h>
-
-#include <stdlib.h>
-#include <unistd.h>
-
-#include <kurl.h>
-#include <kdebug.h>
-#include <kprotocolmanager.h>
-#include <kglobal.h>
-#include <kstandarddirs.h>
-
-#include <kio/slaveconfig.h>
-#include <kio/jobclasses.h>
-#include <kio/scheduler.h>
-#include <kio/netaccess.h>
-
-#include <qwidget.h>
-#include <qapplication.h>
 #include <qregexp.h>
 
-#include "board.h"
-#include "kita_misc.h"
-#include "qcp932codec.h"
-#include "threadinfo.h"
 
 using namespace Kita;
 
 QDict<Thread>* Thread::m_threadDict = 0;
 
-Thread::Thread()
-{}
-
-Thread::Thread( const QString& datURL, const QString& threadName )
-        : m_datURL( datURL ), m_threadName( threadName )
+Thread::Thread( const KURL& datURL )
+    : m_datURL( datURL ), m_threadName( 0 ) , m_resNum( 0 ), m_readNum( 0 ), m_viewPos( 0 ), m_isOpened( 0 )
 {}
 
 Thread::~Thread()
 {}
 
-const QString& Thread::datURL() const
+const KURL& Thread::datURL() const
 {
     return m_datURL;
 }
-const QString Thread::url() const
-{
-    return datToThread( m_datURL );
-}
 
-int Thread::resNum() const
+/* public */
+const QString& Thread::threadName() const
 {
-    return KitaThreadInfo::resNum( m_datURL );
-}
-
-const QString& Thread::name() const
-{
-    if ( ! Kita::Thread::getByURL( m_datURL ) ->m_threadName.isEmpty() ) {
-        return Kita::Thread::getByURL( m_datURL ) ->m_threadName;
-    }
     return m_threadName;
 }
 
-const QString& Thread::boardName() const
+/* public */
+void Thread::setThreadName( QString threadName )
 {
-    return Kita::Board::getName( datToBoard( m_datURL ) );
+    /* remove space */
+    QRegExp qrx(" +$");    
+    threadName.replace( qrx, "" );
+
+    /* unescape */
+    threadName.replace( "&lt;", "<" ).replace( "&gt;", ">" ).replace( "&amp;", "&" );
+    
+    m_threadName = threadName;
 }
 
-Thread* Thread::getByURL( const QString& datURL )
+/* public */
+const int Thread::resNum() const
+{
+    return m_resNum;
+}
+
+/* public */
+void Thread::setResNum( int num )
+{
+    m_resNum = num;
+}
+
+/* public */
+const int Thread::readNum() const
+{
+    return m_readNum;
+}
+
+/* public */
+void Thread::setReadNum( int num )
+{
+    m_readNum = num;
+    if ( m_resNum < m_readNum ) setResNum( m_readNum );
+}
+
+/* public */
+const int Thread::viewPos() const
+{
+    return m_viewPos;
+}
+
+/* public */
+void Thread::setViewPos( int num )
+{
+    m_viewPos = num;
+}
+
+
+/* public */
+bool Thread::isOpened() const
+{
+    return m_isOpened;
+}
+
+/* public */
+void Thread::setIsOpened( bool isOpened )
+{
+    m_isOpened = isOpened;
+}
+
+
+/*--------------------------------------------*/
+
+/* static functions */
+
+Thread* Thread::getByURL( const KURL& datURL )
 {
     if ( m_threadDict == 0 ) {
         m_threadDict = new QDict<Thread>();
     }
 
-    Thread* thread = m_threadDict->find( datURL );
+    Thread* thread = m_threadDict->find( datURL.prettyURL() );
     if ( thread ) return thread;
 
     Thread* newThread = new Thread( datURL );
-    m_threadDict->insert( datURL, newThread );
+    m_threadDict->insert( datURL.prettyURL(), newThread );
 
     return newThread;
 }
@@ -99,32 +126,9 @@ Thread* Thread::getByURLNew( const KURL& datURL )
     return m_threadDict->find( datURL.prettyURL() );
 }
 
-void Thread::setName( const QString& datURL, QString threadName )
-{
-    QRegExp qrx(" +$");    
-    threadName.replace( qrx, "" );
-    
-    if ( datURL.isNull() ) {
-        return ;
-    }
-
-    if ( m_threadDict == 0 ) {
-        m_threadDict = new QDict<Thread>();
-    }
-
-    if ( m_threadDict->find( datURL ) ) {
-        Thread * thread = getByURL( datURL );
-        thread->m_threadName = threadName;
-    } else {
-        Thread* newThread = new Thread( datURL, threadName );
-        m_threadDict->insert( datURL, newThread );
-    }
-
-    return ;
-}
-
 void Thread::replace( const QString& fromURL, const QString& toURL )
 {
+    if( m_threadDict == NULL ) return;
     QDictIterator<Kita::Thread> it( *m_threadDict );
     for( ; it.current(); ++it ) {
         QString url = it.currentKey();
@@ -133,15 +137,8 @@ void Thread::replace( const QString& fromURL, const QString& toURL )
             m_threadDict->remove( url );
             url = url.replace( 0, fromURL.length(), toURL );
             thread->m_datURL = url;
-            Kita::Board::replace( fromURL, toURL );
             m_threadDict->insert( url, thread );
             it.toFirst();
         }
     }
 }
-
-NullThread::NullThread()
-{}
-
-NullThread::~NullThread()
-{}
