@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003,2004 by Hideki Ikemoto , 2004 by 421               *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -29,8 +29,9 @@
 
 #include "libkita/kitaconfig.h"
 #include "libkita/datmanager.h"
+#include "libkita/boardmanager.h"
 #include "libkita/datinfo.h"
-#include "libkita/parsemisc.h"
+#include "libkita/kita_misc.h"
 #include "libkita/signalcollection.h"
 #include "libkita/imgmanager.h"
 
@@ -67,32 +68,45 @@ void KitaHTMLPart::clearPart()
 {
 
     slotDeletePopup();
-
+    
     /* delete KitaDomTree */
     if ( m_domtree ) delete m_domtree;
     m_domtree = NULL;
 
-    /* update Kokomade Yonda */
+    /* update ViewPos */
     if ( m_mode == HTMLPART_MODE_MAINPART && !m_updatedKokoyon && !m_datURL.isEmpty() ) {
         int readNum = Kita::DatManager::getReadNum( m_datURL );
-        if ( readNum ) Kita::DatManager::setKokoyonNum( m_datURL, readNum );
+        if ( readNum ){
+	    Kita::DatManager::setViewPos( m_datURL, readNum );
+	}
     }
     m_updatedKokoyon = FALSE;
-
-    if ( !m_datURL.isEmpty() ) {
-
-        /* don't forget to unlock previous datURL here. */
-        Kita::DatManager::unlock( m_datURL );
-
-        /* emit deactivated all thread view SIGNAL */
-        if ( m_mode == HTMLPART_MODE_MAINPART ) emit activateThreadView( QString::null );
-
-    }
-
+    
+    /* clear variables */
     m_anchorStack.clear();
     m_centerNum = 0;
     m_jumpNumAfterLoading = 0;
     findTextInit();
+
+    if ( !m_datURL.isEmpty() ) {  /* This part is opened. */
+
+        /* don't forget to unlock previous datURL here. */
+        Kita::DatManager::unlock( m_datURL );
+
+        if ( m_mode == HTMLPART_MODE_MAINPART ){ /* This part is on the main thread view. */
+
+	    /* tell Thread class that "thread is closed" */	    
+	    Kita::DatManager::setMainThreadOpened( m_datURL, FALSE );
+	    
+	    /* emit "deactivated all thread view" SIGNAL */	    
+	    emit activateThreadView( QString::null );
+
+	    /*  update subject tab. */
+	    emit updateSubjectTab( m_datURL );
+	}
+    }
+    m_datURL = QString::null;
+    m_mode = HTMLPART_MODE_KHTML;
 }
 
 
@@ -104,22 +118,35 @@ bool KitaHTMLPart::setup( int mode, const KURL& url )
 
     clearPart();
 
-    /* Lock datURL. Don't forget to unlock it later ! */
-    m_datURL = Kita::ParseMisc::parseURLonly( url );
-    Kita::DatManager::lock ( m_datURL );
+    m_datURL = Kita::getDatURL( url );
+    m_mode = mode;
+    
+    if( m_mode == HTMLPART_MODE_MAINPART ){ /* This part is on the main thread view. */
 
-    /* reset abone */
-    Kita::DatManager::resetAbone( m_datURL );
+	/* create DatInfo explicitly to open new thread.   */
+	/* Usually, DatInfo is NOT created if ReadNum == 0.*/
+	/* See also DatManager::createDatInfo() and        */
+	/*          DatManager::getDatInfo().              */
+	Kita::DatManager::createDatInfo( m_datURL );
+
+	/* tell Thread class that "thread is opend" */
+	Kita::DatManager::setMainThreadOpened( m_datURL, TRUE );
+
+	/* reset abone */
+	Kita::DatManager::resetAbone( m_datURL );
+    }
+    
+    /* Lock datURL. Don't forget to unlock it later ! */
+    Kita::DatManager::lock ( m_datURL );
 
     /* create HTML Document */
     createHTMLDocument();
 
     /* create DOM manager */
-    m_mode = mode;
     if ( m_mode == HTMLPART_MODE_MAINPART || m_mode == HTMLPART_MODE_NAVI ) {
         m_domtree = new KitaDomTree( htmlDocument(), m_datURL );
     }
-
+    
     return TRUE;
 }
 
@@ -185,6 +212,10 @@ void KitaHTMLPart::connectSignals()
     /* image viewer */
     connect( this, SIGNAL( redrawImage( const KURL& ) ),
              signalCollection, SIGNAL( redrawImage( const KURL& ) ) );
+
+    /* subject tab */
+    connect( this, SIGNAL( updateSubjectTab( const KURL& ) ),
+             signalCollection, SIGNAL( updateSubjectTab( const KURL& ) ) );
 }
 
 
@@ -239,7 +270,7 @@ void KitaHTMLPart::showResponses( int startnum, int endnum )
 {
     if ( !m_domtree ) return ;
 
-    for ( int i = startnum ; i <= endnum; i++ ) m_domtree->appendRes( i, FALSE );
+    for ( int i = startnum ; i <= endnum; i++ ) m_domtree->appendRes( i );
 }
 
 
@@ -249,7 +280,7 @@ void KitaHTMLPart::parseResponses( int startnum, int endnum )
 {
     if ( !m_domtree ) return ;
 
-    for ( int i = startnum ; i <= endnum; i++ ) m_domtree->parseRes( i, i );
+    for ( int i = startnum ; i <= endnum; i++ ) m_domtree->parseRes( i );
 }
 
 
@@ -267,8 +298,14 @@ void KitaHTMLPart::showAll()
     int bottom = m_domtree->getBottomResNumber();
     int readNum = Kita::DatManager::getReadNum( m_datURL );
     if ( top != 1 || bottom != readNum ) {
+
+        QCursor qc; qc.setShape( Qt::WaitCursor );
+        QApplication::setOverrideCursor( qc );
+
         showResponses( 1, readNum );
-        updateScreen( TRUE, TRUE );
+        updateScreen( TRUE, FALSE );
+
+        QApplication::restoreOverrideCursor();
     }
 }
 
@@ -327,13 +364,10 @@ void KitaHTMLPart::updateScreen( bool showHeaderEtc, bool clock )
 
     /* show header, footer, and kokomadeyonda, etc. */
     if ( showHeaderEtc ) {
-
-        int readNum = Kita::DatManager::getReadNum( m_datURL );
-
         m_domtree->appendMae100();
         m_domtree->appendTugi100();
         m_domtree->appendKokoyon();
-        m_domtree->appendFooter( readNum );
+        m_domtree->appendFooterAndHeader();
     }
 
     /*----------------------------*/
@@ -448,7 +482,7 @@ bool KitaHTMLPart::load( int centerNum )
     if ( !m_domtree ) return FALSE;
     if ( Kita::DatManager::getReadNum( m_datURL ) == 0 ) return FALSE;
 
-    m_domtree->appendTemplate();
+    m_domtree->appendTemplate( 0 );
     showResponses( m_centerNum - showNum, m_centerNum + showNum );
     updateScreen( TRUE , FALSE );
     gotoAnchor( QString().setNum( m_centerNum ), FALSE );
@@ -480,7 +514,6 @@ bool KitaHTMLPart::reload( int jumpNum )
         return FALSE;
     }
 
-    m_domtree->StopParseThread();
     m_firstReceive = TRUE;
     if ( m_centerNum == 0 ) m_centerNum = m_domtree->getBottomResNumber();
     m_jumpNumAfterLoading = jumpNum;
@@ -603,7 +636,7 @@ bool KitaHTMLPart::gotoAnchor( const QString& anc, bool pushPosition )
                 showResponses( bottom + 1, res );
                 updateScreen( TRUE, TRUE );
             } else if ( res < top ) {
-                m_domtree->appendTemplate();
+                m_domtree->appendTemplate( 0 );
                 showResponses( res, bottom );
                 updateScreen( TRUE , TRUE );
             }
@@ -628,7 +661,7 @@ void KitaHTMLPart::slotGotoKokoyon()
     if ( !m_domtree ) return ;
     if ( m_mode != HTMLPART_MODE_MAINPART ) return ;
 
-    int kokoyon = Kita::DatManager::getKokoyonNum( m_datURL );
+    int kokoyon = Kita::DatManager::getViewPos( m_datURL );
     gotoAnchor( QString().setNum( kokoyon ), FALSE );
 }
 
@@ -740,7 +773,7 @@ void KitaHTMLPart::slotClickMae100()
     int bottom = m_domtree->getBottomResNumber();
 
     if ( top != 1 ) {
-        m_domtree->appendTemplate();
+        m_domtree->appendTemplate( 0 );
         showResponses( top - 100, bottom );
         updateScreen( TRUE, TRUE );
 
@@ -779,8 +812,7 @@ void KitaHTMLPart::slotClickTmpNext100()
     int tmpnum = m_domtree->getTemplateNumber();
 
     if ( tmpnum < top ) {
-        m_domtree->setTemplateNumber( tmpnum + 100 );
-        m_domtree->appendTemplate();
+        m_domtree->appendTemplate( tmpnum + 100 );
         showResponses( top, bottom );
         updateScreen( TRUE, TRUE );
 
@@ -800,8 +832,14 @@ void KitaHTMLPart::slotClickShowAll()
     int readNum = Kita::DatManager::getReadNum( m_datURL );
 
     if ( top != 1 || bottom != readNum ) {
+
+        QCursor qc; qc.setShape( Qt::WaitCursor );
+        QApplication::setOverrideCursor( qc );
+
         showResponses( 1, readNum );
-        updateScreen( TRUE, TRUE );
+        updateScreen( TRUE, FALSE );
+
+        QApplication::restoreOverrideCursor();
 
         gotoAnchor( "header", FALSE );
     }
@@ -1009,7 +1047,7 @@ void KitaHTMLPart::showPopupMenu( const KURL& kurl )
             if ( Kita::ImgManager::code( kurl ) == 200 && Kita::ImgManager::mosaic( kurl ) )
                 popupMenu->insertItem( i18n( "Cancel mosaic" ), ID_Mosaic );
 
-            popupMenu->insertItem( i18n( "Open with Image view" ), ID_Show_Imgview );
+            popupMenu->insertItem( i18n( "Open with Image viewer" ), ID_Show_Imgview );
 
             if ( Kita::ImgManager::code( kurl ) == 200 )
                 popupMenu->insertItem( i18n( "Delete" ) , ID_Del_Image );
@@ -1043,7 +1081,7 @@ void KitaHTMLPart::showPopupMenu( const KURL& kurl )
 
         /* mark */
         /* !! very dangerous to call DatManager::getDatInfoPointer without locking !! */
-        Kita::DatManager::lock ( m_datURL );
+        Kita::DatManager::lock ( m_datURL );	
         Kita::DatInfo* datInfo = Kita::DatManager::getDatInfoPointer( m_datURL );
         for ( int i = 1; i <= datInfo->getReadNum() ; i++ ) {
             if ( datInfo->isMarked( i ) ) {
@@ -1069,7 +1107,7 @@ void KitaHTMLPart::showPopupMenu( const KURL& kurl )
 
             if ( m_domtree->isMae100Shown() ) popupMenu->insertItem( i18n( "template" ), ID_Temp_Link );
 
-            int kokoyon = Kita::DatManager::getKokoyonNum( m_datURL );
+            int kokoyon = Kita::DatManager::getViewPos( m_datURL );
             if ( kokoyon ) {
                 str = i18n( "Kokomade Yonda (%1)" ).arg( kokoyon );
                 popupMenu->insertItem( str, ID_Koko_Link );
@@ -1090,9 +1128,16 @@ void KitaHTMLPart::showPopupMenu( const KURL& kurl )
 
         popupMenu->insertItem( "Copy", ID_Copy_Str );
 
-        popupMenu->insertItem( i18n( "Extract by '%1'" ).arg( selectedText() ), ID_Extract );
-        popupMenu->insertItem( i18n( "Add '%1' to abone list" ).arg( selectedText() ), ID_Abone_Word );
-        popupMenu->insertItem( i18n( "Search '%1' by Google" ).arg( selectedText() ), ID_Search_Google );
+        // truncated
+        QString selectedStr = selectedText();
+        if ( selectedStr.length() > 20 ) {
+            selectedStr.truncate( 20 );
+            selectedStr.append( "..." );
+        }
+
+        popupMenu->insertItem( i18n( "Extract by '%1'" ).arg( selectedStr ), ID_Extract );
+        popupMenu->insertItem( i18n( "Add '%1' to abone list" ).arg( selectedStr ), ID_Abone_Word );
+        popupMenu->insertItem( i18n( "Search '%1' by Google" ).arg( selectedStr ), ID_Search_Google );
     }
 
 
@@ -1215,7 +1260,7 @@ void KitaHTMLPart::khtmlMousePressEvent( khtml::MousePressEvent* e )
 
     KURL kurl;
     if ( e->url().string() != QString::null )
-        kurl = KURL( Kita::DatManager::boardURL( m_datURL ), e->url().string() );
+        kurl = KURL( Kita::BoardManager::boardURL( m_datURL ), e->url().string() );
 
     m_pushctrl = m_pushmidbt = m_pushrightbt = FALSE;
     if ( e->qmouseEvent() ->button() & Qt::RightButton ) m_pushrightbt = TRUE;
@@ -1266,7 +1311,7 @@ void KitaHTMLPart::slotOpenURLRequest( const KURL& urlin, const KParts::URLArgs&
 void KitaHTMLPart::clickAnchor( const KURL& urlin )
 {
     QString refstr;
-    KURL datURL = Kita::ParseMisc::parseURL( urlin , refstr );
+    KURL datURL = Kita::getDatURL( urlin , refstr );
 
     /*--------------------*/
     /* Ctrl + right click */
@@ -1521,7 +1566,7 @@ void KitaHTMLPart::showWritePopupMenu( const QString& refstr )
 
         /* url */
         if ( str != QString::null ) str += "\n";
-        str += Kita::DatManager::threadURL( m_datURL ) + QString().setNum( resNum ) + "\n";
+        str += Kita::DatManager::threadURL( m_datURL ) + "/" + QString().setNum( resNum ) + "\n";
 
         /* body */
         if ( ret == WRITEMENU_COPY ) {
@@ -1537,7 +1582,8 @@ void KitaHTMLPart::showWritePopupMenu( const QString& refstr )
 
 
     case WRITEMENU_SETKOKOYON:
-        Kita::DatManager::setKokoyonNum( m_datURL, resNum );
+        Kita::DatManager::setViewPos( m_datURL, resNum );
+	emit updateSubjectTab( m_datURL );
         m_updatedKokoyon = TRUE;
         updateScreen( TRUE, TRUE );
         gotoAnchor( QString().setNum( resNum ), FALSE );
@@ -1942,7 +1988,7 @@ void KitaHTMLPart::slotOnURL( const QString& url )
 
     /* get reference */
     if ( url.at( 0 ) == '#' ) refstr = url.mid( 1 );
-    else datURL = Kita::ParseMisc::parseURL( KURL( m_datURL, url ) , refstr );
+    else datURL = Kita::getDatURL( KURL( m_datURL, url ) , refstr );
 
     int i = refstr.find( "-" );
     if ( i != -1 ) { /* >>refNum-refNum2 */
@@ -1963,9 +2009,15 @@ void KitaHTMLPart::slotOnURL( const QString& url )
     /* another thread ? */
     if ( datURL.host() != m_datURL.host() || datURL.path() != m_datURL.path() ) {
 
-        /* show them with boadname & subject */
-        QString boardName = Kita::DatManager::boardName( datURL );
+        /* get board name */
+        QString boardName = Kita::BoardManager::boardName( datURL );
         if ( boardName != QString::null ) innerHTML += "[" + boardName + "] ";
+
+	/* If idx file of datURL is not read, thread name cannot be obtained.
+	   so, create DatInfo if cache exists, and read idx file in DatInfo::DatInfo(). */
+	Kita::DatManager::getDatInfoPointer( datURL ); 
+
+	/* get thread Name */
         QString subName = Kita::DatManager::threadName( datURL );
         if ( subName != QString::null ) innerHTML += subName + "<br><br>";
 
@@ -1994,7 +2046,7 @@ bool KitaHTMLPart::showSelectedDigitPopup()
     const QChar *chpt = selectText.unicode();
     unsigned int length = selectText.length();
 
-    if ( ( refNum = Kita::ParseMisc::stringToPositiveNum( chpt, length ) ) != -1 ) {
+    if ( ( refNum = Kita::stringToPositiveNum( chpt, length ) ) != -1 ) {
         QString innerHTML = Kita::DatManager::getHtml( m_datURL, refNum, refNum );
         if ( innerHTML != QString::null ) {
             showPopup( m_datURL, innerHTML );
@@ -2065,8 +2117,8 @@ namespace Kita
     /* public */
     void ResPopup::setText( const QString& str )
     {
-	const int maxwd = 1600;
-	const int maxht = 1200;
+        const int maxwd = 1600;
+        const int maxht = 1200;
 
         QString style = QString( "body.pop {"
                                  " font-size: %1pt; "
@@ -2091,7 +2143,7 @@ namespace Kita
         text += "</body></html>";
 
         if ( m_htmlPart ) {
-	      m_htmlPart->view()->resize( maxwd, maxht );	    
+            m_htmlPart->view() ->resize( maxwd, maxht );
             m_htmlPart->setJScriptEnabled( false );
             m_htmlPart->setJavaEnabled( false );
             m_htmlPart->begin( "file:/dummy.htm" );
@@ -2105,74 +2157,74 @@ namespace Kita
     /* public */
     void ResPopup::adjustSize()
     {
-	if( !m_htmlPart ) return;
-	
-	int width = 0, xx = 0, leftmrg = 0;
-	int maxwidth = 0, maxheight = 0;	
-	DOM::Node curnode = m_htmlPart->htmlDocument().body().firstChild();
-	
-	for(;;){
+        if ( !m_htmlPart ) return ;
 
-	    QRect qr = curnode.getRect();
-	    int tmpwd = qr.right() - qr.left();
-		
-	    /*----------------------------------*/
+        int width = 0, xx = 0, leftmrg = 0;
+        int maxwidth = 0, maxheight = 0;
+        DOM::Node curnode = m_htmlPart->htmlDocument().body().firstChild();
 
-	    if ( curnode.nodeType() == DOM::Node::TEXT_NODE ) {
-		if( xx == 0 ) xx = qr.left();
-		width += tmpwd;
-	    }
+        for ( ;; ) {
 
-	    /*----------------------------------*/
-	    
-	    else if( curnode.nodeName().string() == "div" ){
-		if( leftmrg == 0 ) leftmrg = qr.left();
-		width = 0;
-		xx = 0;
-	    }
-	    
-	    /*----------------------------------*/
-	    
-	    else if( curnode.nodeName().string() == "br" ){
-		width = 0;
-		xx = 0;
-	    }
+            QRect qr = curnode.getRect();
+            int tmpwd = qr.right() - qr.left();
 
-	    /*----------------------------------*/
-	    
-	    else if( curnode.nodeName().string() == "table" ) {
-		xx = qr.left();		
-		width = tmpwd;
-	    }
+            /*----------------------------------*/
 
-	    /*----------------------------------*/
-	    
-	    if( leftmrg + xx + width > maxwidth ) maxwidth = leftmrg + xx + width;
-	    if( qr.bottom() > maxheight ) maxheight = qr.bottom();
-	    
-	    /* move to the next node */	    
-	    if( curnode.nodeName().string() == "table" ) curnode = curnode.nextSibling();
-	    else{
-		
-		DOM::Node next = curnode.firstChild();
-		
-		if ( next.isNull() ) next = curnode.nextSibling();
+            if ( curnode.nodeType() == DOM::Node::TEXT_NODE ) {
+                if ( xx == 0 ) xx = qr.left();
+                width += tmpwd;
+            }
 
-		while ( !curnode.isNull() && next.isNull() ) {
-		    curnode = curnode.parentNode();
-		    if ( !curnode.isNull() ) next = curnode.nextSibling();
-		}
+            /*----------------------------------*/
 
-		curnode = next;
-	    }
-	    
-	    if( curnode.isNull() ) break;
-	}
+            else if ( curnode.nodeName().string() == "div" ) {
+                if ( leftmrg == 0 ) leftmrg = qr.left();
+                width = 0;
+                xx = 0;
+            }
 
-	const int mrg = 32;
-		
-	int wd = maxwidth + mrg;
-	int ht = maxheight + mrg;
+            /*----------------------------------*/
+
+            else if ( curnode.nodeName().string() == "br" ) {
+                width = 0;
+                xx = 0;
+            }
+
+            /*----------------------------------*/
+
+            else if ( curnode.nodeName().string() == "table" ) {
+                xx = qr.left();
+                width = tmpwd;
+            }
+
+            /*----------------------------------*/
+
+            if ( leftmrg + xx + width > maxwidth ) maxwidth = leftmrg + xx + width;
+            if ( qr.bottom() > maxheight ) maxheight = qr.bottom();
+
+            /* move to the next node */
+            if ( curnode.nodeName().string() == "table" ) curnode = curnode.nextSibling();
+            else {
+
+                DOM::Node next = curnode.firstChild();
+
+                if ( next.isNull() ) next = curnode.nextSibling();
+
+                while ( !curnode.isNull() && next.isNull() ) {
+                    curnode = curnode.parentNode();
+                    if ( !curnode.isNull() ) next = curnode.nextSibling();
+                }
+
+                curnode = next;
+            }
+
+            if ( curnode.isNull() ) break;
+        }
+
+        const int mrg = 32;
+
+        int wd = maxwidth + mrg;
+        int ht = maxheight + mrg;
 
         m_htmlPart->view() ->resize( wd, ht );
         QFrame::adjustSize();
