@@ -1,5 +1,5 @@
 /***************************************************************************
-*   Copyright (C) 2003 by Hideki Ikemoto , 2004 by 421                    *
+*   Copyright (C) 2004 by Kita Developers                                 *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -12,7 +12,7 @@
 #define KITAHTMLPART_H
 
 #include <khtml_part.h>
-#include <qtextbrowser.h>
+#include <qframe.h>
 
 /* mode */
 enum {
@@ -30,11 +30,8 @@ enum {
 };
 
 
-class KitaHTMLPart;
 class KitaDomTree;
-class KitaThreadView;
 class KitaImgView;
-class KPopupMenu;
 class KURL;
 
 namespace Kita
@@ -233,6 +230,9 @@ signals:
 
     /* image viewr */
     void redrawImage( const KURL& );
+
+    /* subject tab */
+    void updateSubjectTab( const KURL& );
 };
 
 
@@ -249,7 +249,6 @@ namespace Kita
         Q_OBJECT
 
         KitaHTMLPart* m_htmlPart;
-        QTextBrowser* m_textBrowser;
         KitaImgView* m_imgview;
         KURL m_url;
 
