@@ -43,18 +43,14 @@
 #include <qpopupmenu.h>
 
 #include "kitahtmlpart.h"
-#include "kitawritedialog.h"
-#include "kita2ch.h"
 
 #include "libkita/kitaconfig.h"
 #include "libkita/kita-utf8.h"
-#include "libkita/threadinfo.h"
 #include "libkita/qcp932codec.h"
 #include "libkita/favoritethreads.h"
 #include "libkita/favoriteboards.h"
 #include "libkita/datmanager.h"
-#include "libkita/parsemisc.h"
-#include "libkita/board.h"
+#include "libkita/boardmanager.h"
 #include "libkita/signalcollection.h"
 #include "libkita/kita_misc.h"
 
@@ -134,8 +130,12 @@ KitaThreadView::KitaThreadView( QWidget* parent, const char* name )
              signalCollection, SIGNAL( updateSubjectTab( const KURL& ) ) );
     connect( this, SIGNAL( updateThreadTab( const KURL& ) ),
              signalCollection, SIGNAL( updateThreadTab( const KURL& ) ) );
-    connect( this, SIGNAL( openBoardRequested( const QString&, bool ) ),
-             signalCollection, SIGNAL( openBoardRequested( const QString&, bool ) ) );
+    connect( this, SIGNAL( openURLRequestExt(
+                               const KURL&, const KParts::URLArgs&, QString, int, int,
+                               const KURL&, const KURL&, const QString&, const QString& ) ),
+             signalCollection, SIGNAL( openURLRequestExt(
+                                           const KURL& , const KParts::URLArgs&, QString, int, int,
+                                           const KURL&, const KURL&, const QString&, const QString& ) ) );
     connect( this, SIGNAL( setMainCaption( const QString& ) ),
              signalCollection, SIGNAL( setMainCaption( const QString& ) ) );
     connect( this, SIGNAL( closeThreadTab( const KURL& ) ),
@@ -149,8 +149,11 @@ KitaThreadView::KitaThreadView( QWidget* parent, const char* name )
              signalCollection, SIGNAL( showKitaNaviByWord( const KURL& , QString ) ) );
 
     /* write dock */
-    connect( this, SIGNAL( showWriteView( const KURL& , const QString&, const QString& ) ),
-             signalCollection, SIGNAL( showWriteView( const KURL& , const QString&, const QString& ) ) );
+    connect( this, SIGNAL( showWriteView( const KURL& , const QString& ) ),
+             signalCollection, SIGNAL( showWriteView( const KURL& , const QString& ) ) );
+    connect( this, SIGNAL( createNewThread( const KURL& , const QString&, const QString& ) ),
+             signalCollection, SIGNAL( createNewThread( const KURL& , const QString&, const QString& ) ) );
+    
 
     m_viewmode = VIEWMODE_MAINVIEW;
     m_rescode = 200;
@@ -175,7 +178,7 @@ const QString KitaThreadView::threadName() const
 
 const KURL KitaThreadView::threadURL() const
 {
-    return Kita::DatManager::threadURL( m_datURL );
+    return Kita::getThreadURL( m_datURL );
 }
 
 const KURL KitaThreadView::datURL() const
@@ -210,13 +213,13 @@ void KitaThreadView::setSubjectLabel( const QString& boardName, const QString& t
 void KitaThreadView::subjectlinkClicked( const QString& URL )
 {
     kdDebug() << QString( "Jump board: \"%1\"" ).arg( URL ) << endl;
-    emit openBoardRequested( URL, KitaConfig::alwaysUseTab() );
+    emit openURLRequestExt( URL, KParts::URLArgs(), "kita_open_2chboard", KitaConfig::alwaysUseTab() );
 }
 
 void KitaThreadView::subjectlinkMClicked( const QString &URL )
 {
     kdDebug() << QString( "Jump board as new tab: \"%1\"" ).arg( URL ) << endl;
-    emit openBoardRequested( URL, TRUE );
+    emit openURLRequestExt( URL, KParts::URLArgs(), "kita_open_2chboard", 1 );
 }
 
 void KitaThreadView::updateButton()
@@ -247,7 +250,7 @@ void KitaThreadView::updateButton()
 /*--------------------*/  /* private slots */
 void KitaThreadView::slotWriteButtonClicked( QString resstr )
 {
-    emit showWriteView( m_datURL, resstr, m_mailaddr );
+    emit showWriteView( m_datURL, resstr );
 }
 
 
@@ -313,13 +316,7 @@ void KitaThreadView::focusSearchCombo()
 void KitaThreadView::setFocus()
 {
     emit activateThreadView( m_datURL );
-
     showStatusBar( QString::null );
-
-    QWidget* topWidget = topLevelWidget();
-    if ( topWidget->isMinimized() ) topWidget->showNormal();
-    topWidget->raise();
-    topWidget->setActiveWindow();
     m_threadPart->view() ->setFocus();
 }
 
@@ -422,7 +419,7 @@ namespace Kita
     void KitaSubjectLabel::popupCopyToClipboard()
     {
         QClipboard * clipboard = QApplication::clipboard();
-        QString text = QString( "%1\n%2" ).arg( Kita::Board::getName( m_popupURL ) ).arg( m_popupURL );
+        QString text = QString( "%1\n%2" ).arg( Kita::BoardManager::boardName( m_popupURL ) ).arg( m_popupURL );
         kdDebug() << "popupCopytoClipboard :" << endl << text << endl;
         clipboard->setText( text , QClipboard::Clipboard );
         clipboard->setText( text , QClipboard::Selection );
@@ -454,14 +451,11 @@ void KitaThreadView::setup( const KURL& datURL, int mode )
 {
     /* config. */
 
-    /* default name */
-    m_mailaddr = "sage";
-
     /*---------------------------------------*/
     /* setup                                 */
 
-    m_datURL = Kita::ParseMisc::parseURLonly( datURL );
-
+    m_datURL = Kita::getDatURL( datURL );
+   
     /* setup HTMLPart */
     int partMode = HTMLPART_MODE_MAINPART;
     if ( mode == VIEWMODE_KITANAVI ) partMode = HTMLPART_MODE_NAVI;
@@ -472,6 +466,9 @@ void KitaThreadView::setup( const KURL& datURL, int mode )
 
     /* reset search direction */
     m_revsearch = FALSE;
+
+    /* load SETTING.TXT */
+    Kita::BoardManager::loadBBSSetting( m_datURL, FALSE );
 }
 
 
@@ -484,7 +481,7 @@ void KitaThreadView::showThread( const KURL& datURL, int num )
     /* If this widget is not parent, then do nothing. */
     if ( m_viewmode != VIEWMODE_MAINVIEW ) return ;
 
-    if ( num == 0 ) num = Kita::DatManager::getKokoyonNum( datURL );
+    if ( num == 0 ) num = Kita::DatManager::getViewPos( datURL );
 
     if ( topLevelWidget() ->isMinimized() ) topLevelWidget() ->showNormal();
     topLevelWidget() ->raise();
@@ -513,7 +510,7 @@ void KitaThreadView::slotReloadButton( int jumpNum )
     setActiveWindow();
 
     if ( m_threadPart->reload( jumpNum ) ) {
-        showStatusBar( Kita::ParseMisc::utf8ToUnicode( KITAUTF8_NOWRENEW ) );
+        showStatusBar( Kita::utf8ToUnicode( KITAUTF8_NOWRENEW ) );
     }
 }
 
@@ -544,21 +541,18 @@ void KitaThreadView::slotStopLoading()
 void KitaThreadView::showStatusBar( QString info )
 {
     if ( m_datURL.isEmpty() ) return ;
-    int totalNum = 0, datSize = 0;;
-    bool broken = FALSE;
     QString captionStr = QString::null;
     QString infostr = QString::null;
     QString errstr = QString::null;
-    int kokoyonNum = Kita::DatManager::getKokoyonNum( m_datURL );
+    int viewPos = Kita::DatManager::getViewPos( m_datURL );
+    int resNum = Kita::DatManager::getResNum( m_datURL );
+    bool broken = Kita::DatManager::isBroken( m_datURL );
+    int datSize = Kita::DatManager::getDatSize( m_datURL );
 
     switch ( m_viewmode ) {
 
     case VIEWMODE_MAINVIEW:
 
-        totalNum = Kita::DatManager::getReadNum( m_datURL );
-        broken = Kita::DatManager::isBroken( m_datURL );
-        datSize = Kita::DatManager::getDatSize( m_datURL );
-
         errstr = QString::null;
         if ( m_rescode != 200 && m_rescode != 206 && m_rescode != 0 )
             errstr = QString( "Error %1" ).arg( m_rescode );
@@ -566,15 +560,14 @@ void KitaThreadView::showStatusBar( QString info )
 
         /* show status bar,caption, url  */
         infostr = Kita::DatManager::threadName( m_datURL ) +
-                  QString( " [Total: %1 New: %2] %3 k" ).arg( totalNum ).arg( totalNum - kokoyonNum ).arg( datSize / 1024 )
+                  QString( " [Total: %1 New: %2] %3 k" ).arg( resNum ).arg( resNum - viewPos ).arg( datSize / 1024 )
                   + info + " " + errstr;
 
-        captionStr = Kita::DatManager::thread_name( m_datURL )
-                     + QString( " (%1)" ).arg( Kita::DatManager::getReadNum( m_datURL ) );
+        captionStr = Kita::DatManager::threadName( m_datURL ) + QString( " (%1)" ).arg( viewPos );
 
         emit setMainCaption( captionStr );
         emit setMainStatusbar( infostr );
-        emit setMainURLLine( Kita::DatManager::threadURL( m_datURL ) );
+        emit setMainURLLine( Kita::getThreadURL( m_datURL ) );
 
         return ;
         break;
@@ -596,20 +589,20 @@ void KitaThreadView::slotUpdateInfo()
     m_serverTime = Kita::DatManager::getServerTime( m_datURL );
 
     /* uptate informations */
-    setSubjectLabel( Kita::DatManager::thread_boardName( m_datURL ),
-                     Kita::DatManager::thread_name( m_datURL )
+    setSubjectLabel( Kita::BoardManager::boardName( m_datURL ),
+                     Kita::DatManager::threadName( m_datURL )
                      + QString( " (%1)" )
                      .arg( Kita::DatManager::getReadNum( m_datURL ) ),
-                     Kita::DatManager::thread_boardURL( m_datURL ) );
+                     Kita::BoardManager::boardURL( m_datURL ) );
     updateButton();
 
     gotoCombo->clear();
-    gotoCombo->insertItem( Kita::ParseMisc::utf8ToUnicode( KITAUTF8_GOTO ) );
-    gotoCombo->insertItem( Kita::ParseMisc::utf8ToUnicode( KITAUTF8_KOKOYON ) );
+    gotoCombo->insertItem( Kita::utf8ToUnicode( KITAUTF8_GOTO ) );
+    gotoCombo->insertItem( Kita::utf8ToUnicode( KITAUTF8_KOKOYON ) );
     for ( int i = 1; i < Kita::DatManager::getReadNum( m_datURL ); i += 100 ) {
         gotoCombo->insertItem( QString().setNum( i ) + "-" );
     }
-    gotoCombo->insertItem( Kita::ParseMisc::utf8ToUnicode( KITAUTF8_SAIGO ) );
+    gotoCombo->insertItem( Kita::utf8ToUnicode( KITAUTF8_SAIGO ) );
     gotoCombo->adjustSize();
 
     emit updateSubjectTab( m_datURL );
@@ -653,6 +646,11 @@ void KitaThreadView::slotSearchButton()
             if ( act ) act->activate();
             return ;
         }
+        /* create new thread */
+        else if ( str.mid( 1, 3 ) == "new" ) {
+	    emit createNewThread( m_datURL, QString::null, QString::null );
+            return ;
+        }	
 
         /* jump */
         QString anc = str.mid( 1 );
@@ -728,9 +726,10 @@ void KitaThreadView::slotDeleteButtonClicked()
                 != QMessageBox::Ok ) return ;
     }
 
-    Kita::DatManager::deleteCache( threadURL() );
-    emit closeThreadTab( m_datURL );
-    emit updateSubjectTab( m_datURL );
+    if( Kita::DatManager::deleteCache( m_datURL ) ){
+	emit closeThreadTab( m_datURL );
+	emit updateSubjectTab( m_datURL );
+    }
 }
 
 void KitaThreadView::slotCloseButton()
@@ -738,6 +737,11 @@ void KitaThreadView::slotCloseButton()
     emit closeCurrentTab();
 }
 
+const QString KitaThreadView::selectedText() const
+{
+    return m_threadPart->selectedText();
+}
+
 /*--------------------------------------------------------*/
 /* These public functions are used for KitaNavi & preview */
 /*--------------------------------------------------------*/
@@ -784,8 +788,8 @@ void KitaThreadView::domApplyChange( QString labelStr,
     if ( comboStr != NULL ) SearchCombo->insertItem( comboStr );
     if ( labelStr != QString::null ) {
         QString str = QString( "<a href=\"%1\">[%2]</a> " )
-                      .arg( Kita::DatManager::thread_boardURL( m_datURL ) )
-                      .arg( Kita::DatManager::thread_boardName( m_datURL ) ) + labelStr;
+                      .arg( Kita::BoardManager::boardURL( m_datURL ) )
+                      .arg( Kita::BoardManager::boardName( m_datURL ) ) + labelStr;
         subjectLabel->setText( str );
     }
 
