@@ -18,11 +18,8 @@
 
 #include <ktextbrowser.h>
 
-#include "kita2ch.h"
-
 class KURL;
 class KitaHTMLPart;
-class KitaWriteDialog;
 
 #include <qvaluestack.h> // for gcc-2.9x
 template <class T> class QValueStack;
@@ -58,6 +55,7 @@ public:
     const QString threadName() const;
     const KURL threadURL() const;
     const KURL datURL() const;
+    const QString selectedText() const;
 
     void setup( const KURL& datURL, int mode );
     void showStatusBar( QString info );
@@ -95,16 +93,12 @@ private:
     int m_serverTime;
     KURL m_datURL;
     KitaHTMLPart* m_threadPart;
-    Kita::PostInfo m_postInfo;
     Kita::KitaSubjectLabel* subjectLabel;
 
     bool m_revsearch;
     int m_viewmode;
     int m_rescode;
 
-    /* for config */
-    QString m_mailaddr;
-
     void appendRes( int startnum, int endnum );
 
     void insertSearchCombo();
@@ -136,14 +130,21 @@ signals:
     void setMainCaption( const QString& captionStr );
     void setMainStatusbar( const QString& statusStr );
     void bookmarked( const QString& datURL, bool on );
-    void openBoardRequested( const QString& URL, bool useTab );
     void showThreadCompleted(); /* to KitaThreadPart */
     void closeThreadTab( const KURL& url );
     void closeCurrentTab(); /* to KitaThreadTabWidget */
+    void openURLRequestExt( const KURL& url, const KParts::URLArgs& args = KParts::URLArgs(),
+                            QString mimetype = QString::null,
+                            int usr1 = 0, int usr2 = 0,
+                            const KURL& usrUrl1 = KURL(),
+                            const KURL& usrUrl2 = KURL(),
+                            const QString& usrStr1 = QString::null,
+                            const QString& usrStr2 = QString::null );
 
     /* kita navi */
     void showKitaNaviByWord( const KURL& , QString );
-    void showWriteView( const KURL& , const QString&, const QString& );
+    void showWriteView( const KURL& , const QString& );
+    void createNewThread( const KURL& , const QString&, const QString& );    
     void activateThreadView( const KURL& );
 };
 
